      PROGRAM MAIN

*  Program to compute the NMSSM Higgs masses, couplings and
*  Branching ratios, with experimental and theoretical constraints
*
*  Input data corresponds to GMSB model. In addition:
*
*      tan(beta) at the scale MZ, lambda at the scale Q2
*
*      The input file contains the starting point and number of MCMC steps
*
*  On output:
*
*      PAR(1) = lambda
*      PAR(2) = kappa
*      PAR(3) = tan(beta)
*      PAR(4) = mu (effective mu term = lambda*s)
*      PAR(5) = Alambda
*      PAR(6) = Akappa
*      PAR(7) = mQ3**2
*      PAR(8) = mU3**2
*      PAR(9) = mD3**2
*      PAR(10) = mL3**2
*      PAR(11) = mE3**2
*      PAR(12) = AU3
*      PAR(13) = AD3
*      PAR(14) = AE3
*      PAR(15) = mQ2**2
*      PAR(16) = mU2**2
*      PAR(17) = mD2**2
*      PAR(18) = mL2**2
*      PAR(19) = mE2**2
*      PAR(20) = M1
*      PAR(21) = M2
*      PAR(22) = M3
*      PAR(23) = MA (diagonal doublet CP-odd mass matrix element)
*      PAR(24) = MP (diagonal singlet CP-odd mass matrix element)
*      PAR(25) = AE2
*
*      All these parameters are assumed to be defined in DRbar at the scale
*      Q2 which is either user defined or computed as (2*mQ2+mU2+mD2)/4
*
*      SMASS(1-3): CP-even masses (ordered)
*
*      SCOMP(1-3,1-3): Mixing angles: if HB(I) are the bare states,
*        HB(I) = Re(H1), Re(H2), Re(S), and HM(I) are the mass eigenstates,
*        the convention is HB(I) = SUM_(J=1,3) SCOMP(J,I)*HM(J)
*        which is equivalent to HM(I) = SUM_(J=1,3) SCOMP(I,J)*HB(J)
*
*      PMASS(1-2): CP-odd masses (ordered)
*
*      PCOMP(1-2,1-2): Mixing angles: if AB(I) are the bare states,
*        AB(I) = Im(H1), Im(H2), Im(S), and AM(I) are the mass eigenstates,
*        the convention is
*        AM(I) = PCOMP(I,1)*(COSBETA*AB(1)+SINBETA*AB(2))
*              + PCOMP(I,2)*AB(3)
*
*      CMASS: Charged Higgs mass
*
*      CU,CD,CV,CJ,CG(i) Reduced couplings of h1,h2,h3 (i=1,2,3) or
*                        a1,a2 (i=4,5) to up type fermions, down type
*                        fermions, gauge bosons, gluons and photons
*                        Note: CV(4)=CV(5)=0
*      CB(I)             Reduced couplings of h1,h2,h3 (i=1,2,3) or
*                        a1,a2 (i=4,5) to b-quarks including DELMB corrections
*
*      WIDTH(i) Total decay width of h1,h2,h3,a1,a2 (i=1..5)
*               with the following branching ratios:
*      BRJJ(i) h1,h2,h3,a1,a2 -> gluon gluon
*      BRMM(i)        "       -> mu mu
*      BRLL(i)        "       -> tau tau
*      BRSS(i)        "       -> ss
*      BRCC(i)        "       -> cc
*      BRBB(i)        "       -> bb
*      BRTT(i)        "       -> tt
*      BRWW(i)        "       -> WW (BRWW(4)=BRWW(5)=0)
*      BRZZ(i)        "       -> ZZ (BRZZ(4)=BRZZ(5)=0)
*      BRGG(i)        "       -> gamma gamma
*      BRZG(i)        "       -> Z gamma
*      BRHIGGS(i)   (i=1..5)  -> other Higgses, including:
*        BRHAA(i,j)   hi      -> a1a1, a1a2, a2a2 (i=1..3, j=1..3)
*        BRHCHC(i)    hi      -> h+h- (i=1..3)
*        BRHAZ(i,j)   hi      -> Zaj  (i=1..3)
*        BRHCW(i)  h1,h2,h3   -> h+W- (i=1..3), a1,a2 -> h+W- (i=4,5)
*        BRHHH(i)     h2      -> h1h1, h3-> h1h1, h1h2, h2h2 (i=1..4)
*        BRAHA(i)     a2      -> a1hi (i=1..3)
*        BRAHZ(i,j)   ai      -> Zhj  (i=1,2, j=1..3)
*      BRSUSY(i)    (i=1..5)  -> susy particles, including:
*        BRNEU(i,j,k)         -> neutralinos j,k (i=1..5, j,k=1..5)
*        BRCHA(i,j)           -> charginos 11, 12, 22 (i=1..5, j=1..3)
*        BRHSQ(i,j)   hi      -> uLuL, uRuR, dLdL, dRdR, t1t1, t2t2,
*                                t1t2, b1b1, b2b2, b1b2 (i=1..3, j=1..10)
*        BRASQ(i,j)   ai      -> t1t2, b1b2 (i=1,2, j=1,2)
*        BRHSL(i,j)   hi      -> lLlL, lRlR, nLnL, l1l1, l2l2, l1l2,
*                                ntnt (i=1..3, j=1..7)
*        BRASL(i)     ai      -> l1l2 (i=1,2)
*
*      HCWIDTH  Total decay width of the charged Higgs
*               with the following branching ratios:
*      HCBRM         h+ -> mu nu_mu
*      HCBRL         "  -> tau nu_tau
*      HCBRSU        "  -> s u
*      HCBRBU        "  -> b u
*      HCBRSC        "  -> s c
*      HCBRBC        "  -> b c
*      HCBRBT        "  -> b t
*      HCBRWHT       "  -> neutral Higgs W+, including:
*        HCBRWH(i)   "  -> H1W+, H2W+, h3W+, a1W+, a2W+ (i=1..5)
*      HCBRSUSY      "  -> susy particles,including
*        HCBRNC(i,j) "  -> neutralino i chargino j (i=1..5, j=1,2)
*        HCBRSQ(i)   "  -> uLdL, t1b1, t1b2, t2b1, t2b2 (i=1..5)
*        HCBRSL(i)   "  -> lLnL, t1nt, t2nt (i=1..3)
*
*      MNEU(i)   Mass of neutralino chi_i (i=1,5, ordered in mass)
*      NEU(i,j)  chi_i components of bino, wino, higgsino u&d, singlino
*                (i,j=1..5)
*
*      MCHA(i)       Chargino masses
*      U(i,j),V(i,j) Chargino mixing matrices
*
*  ERRORS: IFAIL = 0..22
*
*  IFAIL = 0         OK
*          1,3,5,7   m_h1^2 < 0
*          2,3,6,7   m_a1^2 < 0
*          4,5,6,7   m_h+^2 < 0
*          8         m_sfermion^2 < 0
*          9         l, tan(beta) or mu = 0
*          10        Violation of phenomenological constraint(s)
*          11-15     Problem in integration of RGEs
*          16-19     Convergence problem
*          20        No electroweak symmetry breaking
*          21        MSMES=/=MSREF (GMSB scenario above MMESS)
*          22        IFAIL = 10 & 21
*
*  Phenomenological constraints:
*
*      PROB(I)  = 0, I = 1..53: OK
*
*      PROB(1) =/= 0   chargino too light
*      PROB(2) =/= 0   excluded by Z -> neutralinos
*      PROB(3) =/= 0   charged Higgs too light
*      PROB(4) =/= 0   excluded by ee -> hZ
*      PROB(5) =/= 0   excluded by ee -> hZ, h -> bb
*      PROB(6) =/= 0   excluded by ee -> hZ, h -> tautau
*      PROB(7) =/= 0   excluded by ee -> hZ, h -> invisible
*      PROB(8) =/= 0   excluded by ee -> hZ, h -> 2jets
*      PROB(9) =/= 0   excluded by ee -> hZ, h -> 2photons
*      PROB(10) =/= 0  excluded by ee -> hZ, h -> AA -> 4bs
*      PROB(11) =/= 0  excluded by ee -> hZ, h -> AA -> 4taus
*      PROB(12) =/= 0  excluded by ee -> hZ, h -> AA -> 2bs 2taus
*      PROB(13) =/= 0  excluded by Z -> hA (Z width)
*      PROB(14) =/= 0  excluded by ee -> hA -> 4bs
*      PROB(15) =/= 0  excluded by ee -> hA -> 4taus
*      PROB(16) =/= 0  excluded by ee -> hA -> 2bs 2taus
*      PROB(17) =/= 0  excluded by ee -> hA -> AAA -> 6bs
*      PROB(18) =/= 0  excluded by ee -> hA -> AAA -> 6taus
*      PROB(19) =/= 0  excluded by ee -> Zh -> ZAA -> Z + light pairs
*      PROB(20) =/= 0  excluded by stop -> b l sneutrino
*      PROB(21) =/= 0  excluded by stop -> neutralino c
*      PROB(22) =/= 0  excluded by sbottom -> neutralino b
*      PROB(23) =/= 0  squark/gluino too light
*      PROB(24) =/= 0  selectron/smuon too light
*      PROB(25) =/= 0  stau too light
*      PROB(27) =/= 0  Landau Pole in l, k, ht, hb below MGUT
*      PROB(28) =/= 0  unphysical global minimum
*      PROB(29) =/= 0  Higgs soft masses >> Msusy
*      PROB(32) =/= 0  b->s gamma more than 2 sigma away
*      PROB(33) =/= 0  Delta M_s more than 2 sigma away
*      PROB(34) =/= 0  Delta M_d more than 2 sigma away
*      PROB(35) =/= 0  B_s->mu+mu- more than 2 sigma away
*      PROB(36) =/= 0  B+-> tau+nu_tau more than 2 sigma away
*      PROB(37) =/= 0  (g-2)_muon more than 2 sigma away
*      PROB(38) =/= 0  excluded by Upsilon(1S) -> A gamma
*      PROB(39) =/= 0  excluded by eta_b(1S) mass measurement
*      PROB(40) =/= 0  BR(B-->X_s mu+ mu-) more than 2 sigma away
*      PROB(41) =/= 0  excluded by ee -> hZ, h -> AA -> 4taus (ALEPH analysis)
*      PROB(42) =/= 0  excluded by top -> b H+, H+ -> c s (CDF, D0)
*      PROB(43) =/= 0  excluded by top -> b H+, H+ -> tau nu_tau (D0)
*      PROB(44) =/= 0  excluded by top -> b H+, H+ -> W+ A1, A1 -> 2taus (CDF)
*      PROB(45) =/= 0  excluded by t -> bH+ (LHC)
*      PROB(46) =/= 0  No Higgs in the MHmin-MHmax GeV range
*      PROB(47) =/= 0  chi2gam > chi2max
*      PROB(48) =/= 0  chi2bb > chi2max
*      PROB(49) =/= 0  chi2zz > chi2max
*      PROB(50) =/= 0  excluded by sparticle searches at the LHC (not called by default)
*      PROB(51) =/= 0: excluded by H/A->tautau
*      PROB(52) =/= 0: Excluded H_125->AA->4mu (CMS)
*      PROB(53) =/= 0: excluded by ggF->H/A->gamgam (65GeV < M < 122GeV, ATLAS)
*
************************************************************************

      IMPLICIT NONE

      INTEGER NFL,NPROB,NPAR
      PARAMETER (NFL=22,NPROB=53,NPAR=25)
      INTEGER NFAIL(NFL),IFAIL,I,TOT,ITOT,NTOT,IDUM,GMFLAG,LOOP
      INTEGER ITER,ITERMU,Q2FIX,OMGFLAG,MAFLAG,MOFLAG,GMUFLAG,HFLAG
      INTEGER TOTMIN,TOTMAX,NMAX,IP,JM,JL,ITRY,NMSFLAG

      DOUBLE PRECISION PAR(NPAR),PROB(NPROB),CHECK,MESTEST,GUTEST
      DOUBLE PRECISION MSUSYEFFCEN,MSUSYEFFDEV,MMESSCEN,MMESSDEV
      DOUBLE PRECISION TBCEN,TBDEV,LCEN,LDEV,KCEN,KDEV,ALCEN,ALDEV
      DOUBLE PRECISION XIFCEN,XIFDEV,XISCEN,XISDEV,MUPCEN,MUPDEV
      DOUBLE PRECISION MSPCEN,MSPDEV,MSCEN,MSDEV,XIUCEN,XIUDEV
      DOUBLE PRECISION LPPCEN,LPPDEV,LTTCEN,LTTDEV,LUCEN,LUDEV
      DOUBLE PRECISION LDCEN,LDDEV, LTCEN,LTDEV,LBCEN,LBDEV
      DOUBLE PRECISION LLCEN,LLDEV,XCEN,XDEV,X
      DOUBLE PRECISION MSUSYEFFMIN,MMESSMIN,TBMIN,LMIN,KMIN,ALMIN
      DOUBLE PRECISION XIFMIN,XISMIN,MUPMIN,MSPMIN,MSMIN,XIUMIN
      DOUBLE PRECISION LPPMIN,LTTMIN,LUMIN,LDMIN,LTMIN,LBMIN,LLMIN
      DOUBLE PRECISION MSUSYEFFN,MSUSYEFFNN,MMESSN,MMESSNN,TBN,TBNN
      DOUBLE PRECISION LN,LNN,KN,KNN,ALN,ALNN,XIFN,XIFNN,XISN,XISNN
      DOUBLE PRECISION MUPN,MUPNN,MSPN,MSPNN,MSN,MSNN,XIUN,XIUNN
      DOUBLE PRECISION LPPN,LPPNN,LTTN,LTTNN,LUN,LUNN,LDN,LDNN
      DOUBLE PRECISION LTN,LTNN,LBN,LBNN,LLN,LLNN,MUN,MUNN
      DOUBLE PRECISION XIFMES,XISMES,MSMES,MUPMES,MSPMES,M3HMES
      DOUBLE PRECISION ALINP,XIFINP,XISINP,MSINP,MUPINP,MSPINP
      DOUBLE PRECISION MSUSYEFF,MMESS,N5,GAU,DETM,SIGMU,Q2,Q2MIN
      DOUBLE PRECISION ALSMZ,ALEMMZ,GF,g1,g2,S2TW,MSREF,D,DMIN
      DOUBLE PRECISION MS,MC,MB,MBP,MT,MTAU,MMUON,MZ,MW
      DOUBLE PRECISION PI,ALP1,ALP2,DELMB,MUFAIL,M32,CGR,MPL
      DOUBLE PRECISION G1MES,G2MES,G3MES,LMES,KMES,HTMES,HBMES,HLMES
      DOUBLE PRECISION LPPMES,LTTMES,LUMES,LDMES,LTMES,LBMES,LLMES,XIU
      DOUBLE PRECISION MSM,MST,LM,LT,KM,KT,HTM,HTT,LPPM,LPPT,LTTM,LTTT
      DOUBLE PRECISION Q2MEM,DELMEM,XIFMEM,XISMEM,MSMEM
      DOUBLE PRECISION LPPMEM,LTTMEM,PARMEM(25)

      COMMON/NMSFLAG/NMSFLAG
      COMMON/FLAGS/OMGFLAG,MAFLAG,MOFLAG
      COMMON/GMUFLAG/GMUFLAG,HFLAG
      COMMON/GMSCEN/MSREF,D,DMIN,GMFLAG
      COMMON/SIGMU/SIGMU
      COMMON/RENSCALE/Q2
      COMMON/Q2FIX/Q2MIN,Q2FIX
      COMMON/DETM/DETM
      COMMON/MUFAIL/MUFAIL
      COMMON/DELMB/DELMB
      COMMON/MESCAL/MSUSYEFF,MMESS,N5
      COMMON/MESCOUP/G1MES,G2MES,G3MES,LMES,KMES,HTMES,HBMES,HLMES
      COMMON/MESEXT/XIFMES,XISMES,MSMES,MUPMES,MSPMES,M3HMES
      COMMON/MESGUT/LPPMES,LTTMES,LUMES,LDMES,LTMES,LBMES,LLMES,XIU
      COMMON/INPPAR/ALINP,XIFINP,XISINP,MSINP,MUPINP,MSPINP
      COMMON/GAUGE/ALSMZ,ALEMMZ,GF,g1,g2,S2TW
      COMMON/SMSPEC/MS,MC,MB,MBP,MT,MTAU,MMUON,MZ,MW
      COMMON/MCMCPAR/MSUSYEFFCEN,MSUSYEFFDEV,MMESSCEN,MMESSDEV,
     . TBCEN,TBDEV,LCEN,LDEV,KCEN,KDEV,ALCEN,ALDEV,XIFCEN,
     . XIFDEV,XISCEN,XISDEV,MUPCEN,MUPDEV,MSPCEN,MSPDEV,
     . MSCEN,MSDEV,XIUCEN,XIUDEV,LPPCEN,LPPDEV,LTTCEN,LTTDEV,
     . LUCEN,LUDEV,LDCEN,LDDEV, LTCEN,LTDEV,LBCEN,LBDEV,
     . LLCEN,LLDEV,XCEN,XDEV,X,
     . MSUSYEFFMIN,MMESSMIN,TBMIN,LMIN,KMIN,ALMIN,
     . XIFMIN,XISMIN,MUPMIN,MSPMIN,MSMIN,XIUMIN,
     . LPPMIN,LTTMIN,LUMIN,LDMIN,LTMIN,LBMIN,LLMIN
      COMMON/BOUNDS/MSUSYEFFN,MSUSYEFFNN,MMESSN,MMESSNN,TBN,TBNN,
     . LN,LNN,KN,KNN,ALN,ALNN,XIFN,XIFNN,XISN,XISNN,MUPN,MUPNN,
     . MSPN,MSPNN,MSN,MSNN,XIUN,XIUNN,LPPN,LPPNN,LTTN,LTTNN,LUN,LUNN,
     . LDN,LDNN,LTN,LTNN,LBN,LBNN,LLN,LLNN,MUN,MUNN
      COMMON/STEPS/NTOT,IDUM,TOTMIN,TOTMAX,NMAX
      COMMON/GMSAVE/MSM,MST,LM,LT,KM,KT,HTM,HTT,
     . LPPM,LPPT,LTTM,LTTT,JM,JL
      COMMON/GMEM/Q2MEM,DELMEM,XIFMEM,XISMEM,MSMEM,
     . LPPMEM,LTTMEM,PARMEM
      COMMON/M32/M32,CGR,MPL

      PI=4d0*DATAN(1d0)

*   Initialization

      CALL INITIALIZE()
      DO I=1,NFL
       NFAIL(I)=0
      ENDDO
      TOT=0
      IFAIL=-1
      IP=0

*   Reading of the input parameters

      CALL INPUT(PAR,NPAR)

*   Initialization of the range of parameters that has passed all tests

      MSUSYEFFN=1d99
      MSUSYEFFNN=-1d99
      MMESSN=1d99
      MMESSNN=-1d99
      TBN=1d99
      TBNN=-1d99
      LN=1d99
      LNN=-1d99
      ALN=1d99
      ALNN=-1d99
      MUN=1d99
      MUNN=-1d99
      XIFN=1d99
      XIFNN=-1d99
      KN=1d99
      KNN=-1d99
      MSN=1d99
      MSNN=-1d99
      XISN=1d99
      XISNN=-1d99
      MUPN=1d99
      MUPNN=-1d99
      MSPN=1d99
      MSPNN=-1d99
      XIUN=1d99
      XIUNN=-1d99
      LPPN=1d99
      LPPNN=-1d99
      LTTN=1d99
      LTTNN=-1d99
      LUN=1d99
      LUNN=-1d99
      LDN=1d99
      LDNN=-1d99
      LTN=1d99
      LTNN=-1d99
      LBN=1d99
      LBNN=-1d99
      LLN=1d99
      LLNN=-1d99

*   Beginning of the random scan

      DO ITOT=1,NTOT

 14   IF(ITOT.EQ.1)THEN

       MSUSYEFF=MSUSYEFFCEN
       MMESS=MMESSCEN
       PAR(3)=TBCEN
       PAR(1)=LCEN
       IF(MAFLAG.EQ.-1 .OR. MAFLAG.EQ.-2)THEN
        XIFINP=XIFCEN
       ELSE
        PAR(2)=KCEN
       ENDIF
       IF(MAFLAG.EQ.-1 .OR. MAFLAG.EQ.-3)THEN
        XISINP=XISCEN
       ELSE
        MSINP=MSCEN
       ENDIF
       MUPINP=MUPCEN
       MSPINP=MSPCEN
       XIU=XIUCEN
       IF(GMFLAG.NE.0)THEN
        ALINP=-MSUSYEFF/(4d0*PI)**2*(
     .       2d0*LPPMES+3d0*LTTMES+3d0*LUMES+3d0*LDMES)
       ELSE
        ALINP=ALCEN
       ENDIF
       IF(GMFLAG.EQ.2)THEN
        LPPMES=LPPCEN
        LTTMES=LTTCEN
       ENDIF
       LUMES=LUCEN
       LDMES=LDCEN
       LTMES=LTCEN
       LBMES=LBCEN
       LLMES=LLCEN

      ELSE

       IF(MSUSYEFFDEV.EQ.0d0)THEN
        MSUSYEFF=MSUSYEFFCEN
       ELSE
 101    MSUSYEFF=MSUSYEFFCEN
     .  +MAX(DABS(MSUSYEFFCEN),MSUSYEFFMIN)*MSUSYEFFDEV*GAU(IDUM)
        IF(MSUSYEFF.LE.MZ)GOTO 101
       ENDIF
       IF(MMESSDEV.EQ.0d0)THEN
        MMESS=MMESSCEN
       ELSE
 102    MMESS=MMESSCEN**(1d0+MMESSDEV*GAU(IDUM))
	IF(MMESS.GT.1d15)GOTO 102
	IF(MMESS.LT.1d1*MSUSYEFF)GOTO 102
       ENDIF
       IF(TBDEV.EQ.0d0)THEN
        PAR(3)=TBCEN
       ELSE
 103    PAR(3)=TBCEN+MAX(DABS(TBCEN),TBMIN)*TBDEV*GAU(IDUM)
        IF(PAR(3).LT.1d0)GOTO 103
       ENDIF
       IF(LDEV.EQ.0d0)THEN
        PAR(1)=LCEN
       ELSE
 104    PAR(1)=LCEN+MAX(DABS(LCEN),LMIN)*LDEV*GAU(IDUM)
        IF(PAR(1).LT.LMIN)GOTO 104
       ENDIF
       IF(MAFLAG.EQ.-1 .OR. MAFLAG.EQ.-2)THEN
        IF(XIFDEV.EQ.0d0)THEN
         XIFINP=XIFCEN
        ELSE
 106     XIFINP=XIFCEN+MAX(DABS(XIFCEN),XIFMIN)*XIFDEV*GAU(IDUM)
        ENDIF
       ELSE
        IF(KDEV.EQ.0d0)THEN
         PAR(2)=KCEN
        ELSE
 107     PAR(2)=KCEN+MAX(DABS(KCEN),KMIN)*KDEV*GAU(IDUM)
        ENDIF
       ENDIF
       IF(MAFLAG.EQ.-1 .OR. MAFLAG.EQ.-3)THEN
        IF(XISDEV.EQ.0d0)THEN
         XISINP=XISCEN
        ELSE
 108     XISINP=XISCEN+MAX(DABS(XISCEN),XISMIN)*XISDEV*GAU(IDUM)
        ENDIF
       ELSE
        IF(MSDEV.EQ.0d0)THEN
         MSINP=MSCEN
        ELSE
 109     MSINP=MSCEN+MAX(DABS(MSCEN),MSMIN)*MSDEV*GAU(IDUM)
        ENDIF
       ENDIF
       IF(MUPDEV.EQ.0d0)THEN
        MUPINP=MUPCEN
       ELSE
 110    MUPINP=MUPCEN+MAX(DABS(MUPCEN),MUPMIN)*MUPDEV*GAU(IDUM)
       ENDIF
       IF(MSPDEV.EQ.0d0)THEN
        MSPINP=MSPCEN
       ELSE
 111    MSPINP=MSPCEN+MAX(DABS(MSPCEN),MSPMIN)*MSPDEV*GAU(IDUM)
       ENDIF
       IF(XIUDEV.EQ.0d0)THEN
        XIU=XIUCEN
       ELSE
 112    XIU=XIUCEN+MAX(DABS(XIUCEN),XIUMIN)*XIUDEV*GAU(IDUM)
        IF(XIU.LT.XIUMIN)GOTO 112
       ENDIF
       IF(GMFLAG.EQ.2)THEN
        IF(LPPDEV.EQ.0d0)THEN
         LPPMES=LPPCEN
        ELSE
 113     LPPMES=LPPCEN+MAX(DABS(LPPCEN),LPPMIN)*LPPDEV*GAU(IDUM)
        ENDIF
        IF(LTTDEV.EQ.0d0)THEN
         LTTMES=LTTCEN
        ELSE
 114     LTTMES=LTTCEN+MAX(DABS(LTTCEN),LTTMIN)*LTTDEV*GAU(IDUM)
        ENDIF
       ENDIF
       IF(LUDEV.EQ.0d0)THEN
        LUMES=LUCEN
       ELSE
 115    LUMES=LUCEN+MAX(DABS(LUCEN),LUMIN)*LUDEV*GAU(IDUM)
       ENDIF
       IF(LDDEV.EQ.0d0)THEN
        LDMES=LDCEN
       ELSE
 116    LDMES=LDCEN+MAX(DABS(LDCEN),LDMIN)*LDDEV*GAU(IDUM)
       ENDIF
       IF(LTDEV.EQ.0d0)THEN
        LTMES=LTCEN
       ELSE
 117    LTMES=LTCEN+MAX(DABS(LTCEN),LTMIN)*LTDEV*GAU(IDUM)
       ENDIF
       IF(LBDEV.EQ.0d0)THEN
        LBMES=LBCEN
       ELSE
 118    LBMES=LBCEN+MAX(DABS(LBCEN),LBMIN)*LBDEV*GAU(IDUM)
       ENDIF
       IF(LLDEV.EQ.0d0)THEN
        LLMES=LLCEN
       ELSE
 119    LLMES=LLCEN+MAX(DABS(LLCEN),LLMIN)*LLDEV*GAU(IDUM)
       ENDIF
       IF(GMFLAG.NE.0)THEN
        ALINP=-MSUSYEFF/(4d0*PI)**2*
     .        (2d0*LPPMES+3d0*LTTMES+3d0*LUMES+3d0*LDMES)
       ELSE
        IF(ALDEV.EQ.0d0)THEN
         ALINP=ALCEN
        ELSE
 105     ALINP=ALCEN+MAX(DABS(ALCEN),ALMIN)*ALDEV*GAU(IDUM)
        ENDIF
       ENDIF
      ENDIF

!      WRITE(0,*)""
!      WRITE(0,*)"------------------------------------------------------"
!      WRITE(0,*)""
!      WRITE(0,*)"Point ",ITOT
!      WRITE(0,*)""
!      WRITE(0,*)"MAFLAG=",MAFLAG
!      WRITE(0,*)"GMFLAG=",GMFLAG
!      WRITE(0,*)"MSUSYEFFCEN =",MSUSYEFFCEN
!      WRITE(0,*)"MSUSYEFF =",MSUSYEFF
!      WRITE(0,*)"MMESSCEN =",MMESSCEN
!      WRITE(0,*)"MMESS =",MMESS
!      WRITE(0,*)"TANBCEN =",TBCEN
!      WRITE(0,*)"TANB =",PAR(3)
!      WRITE(0,*)"LCEN =",LCEN
!      WRITE(0,*)"LAMBDA =",PAR(1)
!      IF(GMFLAG.EQ.0)THEN
!       WRITE(0,*)"ALAMBDA=",ALINP
!       IF(MAFLAG.EQ.-3 .OR. MAFLAG.EQ.-4)WRITE(0,*)"KAPPA =",PAR(2)
!       IF(MAFLAG.EQ.-1 .OR. MAFLAG.EQ.-2)WRITE(0,*)"XIF =",XIFINP
!       IF(MAFLAG.EQ.-1 .OR. MAFLAG.EQ.-3)WRITE(0,*)"XIS =",XISINP
!       IF(MAFLAG.EQ.-2 .OR. MAFLAG.EQ.-4)WRITE(0,*)"MS =",MSINP
!       IF(MUPINP.NE.0d0)WRITE(0,*)"MUP =",MUPINP
!       IF(MSPINP.NE.0d0)WRITE(0,*)"MSP =",MSPINP
!      ENDIF
!      IF(GMFLAG.EQ.1)THEN
!       WRITE(0,*)"XiUCEN =",XIUCEN
!       WRITE(0,*)"XiU =",XIU
!      ENDIF
!      IF(GMFLAG.EQ.2)THEN
!       WRITE(0,*)"LPP =",LPPMES
!       WRITE(0,*)"LTT =",LTTMES
!      ENDIF
!      IF(GMFLAG.NE.0)THEN
!       WRITE(0,*)"LU =",LUMES
!       WRITE(0,*)"LD =",LDMES
!       WRITE(0,*)"LT =",LTMES
!       WRITE(0,*)"LB =",LBMES
!       WRITE(0,*)"LL =",LLMES
!      ENDIF
!      WRITE(0,*)""
!      WRITE(0,*)""

*   Initialization of PROB

      DO I=1,NPROB
       PROB(I)=0d0
      ENDDO

*   Initialization of algorithm parameters

      JL=0
      LPPT=0d0
      LTTT=0d0
      LOOP=0
 2    LOOP=LOOP+1
!      IF(GMFLAG.EQ.1)THEN
!       WRITE(0,*)"LOOP =",LOOP
!       WRITE(0,*)""
!       WRITE(0,*)""
!      ENDIF
      IF(IFAIL.EQ.-1)THEN
       PAR(4)=SIGMU*N5*MSUSYEFF/(4d0*PI)**2
      ELSEIF(LOOP.EQ.1)THEN
       PAR(4)=PARMEM(4)
      ENDIF
      MUFAIL=1d0
      ITRY=0
 1    ITRY=ITRY+1
!      WRITE(0,*)"ITRY=",ITRY
!      WRITE(0,*)""
!      WRITE(0,*)""
      MST=0d0
      LT=0d0
      KT=0d0
      HTT=0d0
      JM=0

*   Guess parameters at Q2/MMESS

      IF(IFAIL.NE.0)THEN
!       WRITE(0,*)"Guesses"
       IF(Q2FIX.EQ.0)THEN
        Q2=MAX(N5*MSUSYEFF**2/(4d0*PI)**4,Q2MIN)
       ENDIF
       IF(MAFLAG.EQ.-1 .OR. MAFLAG.EQ.-2)THEN
        PAR(2)=PAR(1)/5d0
       ELSE
        XIFMES=MSUSYEFF**2/(4d0*PI)**4
       ENDIF
       IF(MAFLAG.EQ.-1 .OR. MAFLAG.EQ.-3)THEN
        MSM=MSUSYEFF**2/(4d0*PI)**4
       ELSE
        XISMES=MSUSYEFF**3/(4d0*PI)**6
       ENDIF
       IF(GMFLAG.EQ.0)THEN
        PAR(5)=ALINP
       ELSE
        PAR(5)=-MSUSYEFF/(4d0*PI)**2
       ENDIF
       IF(PAR(2).NE.0d0)THEN
        PAR(6)=3d0*PAR(5)
       ELSE
        PAR(6)=0d0
       ENDIF
       DO I=7,11
        PAR(I)=N5*MSUSYEFF**2/(4d0*PI)**4
       ENDDO
       DO I=12,14
        PAR(I)=0d0
       ENDDO
       DO I=15,19
        PAR(I)=N5*MSUSYEFF**2/(4d0*PI)**4
       ENDDO
        DO I=20,22
        PAR(I)=N5*MSUSYEFF/(4d0*PI)**2
       ENDDO
       PAR(23)=MSUSYEFF/(4d0*PI)**2
       PAR(24)=MSUSYEFF/(4d0*PI)**2
       PAR(25)=0d0
       DELMB=.1d0
       IF(GMFLAG.EQ.1)THEN
        LPPM=XIU
        LTTM=XIU
       ENDIF

      ELSEIF(LOOP.EQ.1)THEN
!	WRITE(0,*)"Memorized"
       IF(Q2FIX.EQ.0)THEN
	Q2=Q2MEM
       ENDIF
       IF(MAFLAG.EQ.-1 .OR. MAFLAG.EQ.-2)THEN
	PAR(2)=PARMEM(2)
       ELSE
	XIFMES=XIFMEM
       ENDIF
       IF(MAFLAG.EQ.-1 .OR. MAFLAG.EQ.-3)THEN
	MSM=MSMEM
       ELSE
	XISMES=XISMEM
       ENDIF
       IF(GMFLAG.EQ.0)THEN
	PAR(5)=ALINP
       ELSE
	PAR(5)=PARMEM(5)
       ENDIF
       IF(PAR(2).NE.0d0)THEN
	PAR(6)=PARMEM(6)
       ELSE
	PAR(6)=0d0
       ENDIF
       DO I=7,25
	PAR(I)=PARMEM(I)
       ENDDO
       DELMB=DELMEM
       IF(GMFLAG.EQ.1)THEN
	LPPM=LPPMEM
	LTTM=LTTMEM
       ENDIF

!      ELSE
!       WRITE(0,*)"Current"

      ENDIF
      IFAIL=0

!      WRITE(0,*)""
!      WRITE(0,*)"M1 =",PAR(20)
!      WRITE(0,*)"M2 =",PAR(21)
!      WRITE(0,*)"M3 =",PAR(22)
!      WRITE(0,*)"AL =",PAR(5)
!      WRITE(0,*)"AK =",PAR(6)
!      WRITE(0,*)"ATOP =",PAR(12)
!      WRITE(0,*)"ABOT =",PAR(13)
!      WRITE(0,*)"ATAU =",PAR(14)
!      WRITE(0,*)"AMUON =",PAR(25)
!      WRITE(0,*)"MQ3 =",PAR(7)
!      WRITE(0,*)"MU3 =",PAR(8)
!      WRITE(0,*)"MD3 =",PAR(9)
!      WRITE(0,*)"MQ =",PAR(15)
!      WRITE(0,*)"MU =",PAR(16)
!      WRITE(0,*)"MD =",PAR(17)
!      WRITE(0,*)"ML3 =",PAR(10)
!      WRITE(0,*)"ME3 =",PAR(11)
!      WRITE(0,*)"ML =",PAR(18)
!      WRITE(0,*)"ME =",PAR(19)
!      IF(MAFLAG.EQ.-1 .OR. MAFLAG.EQ.-2)THEN
!       WRITE(0,*)"K =",PAR(2)
!      ELSE
!      WRITE(0,*)"XIF =",XIFMES
!       ENDIF
!      IF(MAFLAG.EQ.-1 .OR. MAFLAG.EQ.-3)THEN
!       WRITE(0,*)"MS =",MSM
!      ELSE
!       WRITE(0,*)"XIS =",XISMES
!      ENDIF
!      WRITE(0,*)"MU =",PAR(4)
!      IF(GMFLAG.EQ.1)THEN
!       WRITE(0,*)"LPP =",LPPM
!       WRITE(0,*)"LTT =",LTTM
!      ENDIF
!      WRITE(0,*)""

*   Check for singular parameters l, tan(beta)

      IF(PAR(1)*PAR(3).EQ.0d0)THEN
       IFAIL=9
       GOTO 11
      ENDIF

*   Guess for couplings at MMESS

      CALL RGESGM(PAR,IFAIL)
      IF(IFAIL.NE.0)THEN
!       WRITE(0,*)"RGE integration problem 1"
!       WRITE(0,*)"Exit (IFAIL=11)"
!       WRITE(0,*)""
!       WRITE(0,*)""
       IFAIL=11
       GOTO 11
      ENDIF

*   External loop to compute the soft parameters at Q2

      ITER=0
 21   ITER=ITER+1
!      WRITE(0,*)"ITER =",ITER
!      WRITE(0,*)""
!      WRITE(0,*)""

      CALL RGESINVGM(PAR,IFAIL)
      IF(IFAIL.NE.0)THEN
!       WRITE(0,*)"RGE integration problem 2"
!       WRITE(0,*)"Exit (IFAIL=13)"
!       WRITE(0,*)""
!       WRITE(0,*)""
       IFAIL=13
       GOTO 11
      ENDIF

*   Internal loop to compute ((k or XiF) and (mS or XiS) and mu)

      ITERMU=0
 22   ITERMU=ITERMU+1
!      WRITE(0,*)"ITERMU =",ITERMU
!      WRITE(0,*)""
!      WRITE(0,*)""

      CALL RUNPAR(PAR)

      CALL MSFERM(PAR,IFAIL,1)
      IF(IFAIL.NE.0)THEN
!       WRITE(0,*)"Negative sfermion mass squared"
!       WRITE(0,*)"Exit (IFAIL=8)"
!       WRITE(0,*)""
!       WRITE(0,*)""
       IFAIL=8
       GOTO 11
      ENDIF

      CALL MINIMIZE(PAR,CHECK)

*   End of the internal loop

      IF((CHECK.GT.1d-12.AND.ITERMU.LT.10).OR.
     .   (CHECK.GT.1d-8.AND.ITERMU.LT.50).OR.
     .   (CHECK.GT.1d-6.AND.ITERMU.LT.100))GOTO 22
      IF(CHECK.GT.1d-4)THEN
!       WRITE(0,*)"No convergence 1"
!       WRITE(0,*)"Exit (IFAIL=16)"
!       WRITE(0,*)""
!       WRITE(0,*)""
       IFAIL=16
       GOTO 11
      ENDIF

      CALL GETSUSYCOUP(PAR,IFAIL)

      CALL RGESUNIGM(PAR,IFAIL,MESTEST)
      IF(IFAIL.NE.0)THEN
!       WRITE(0,*)"RGE integration problem 3"
!       WRITE(0,*)"Exit (IFAIL=12)"
!       WRITE(0,*)""
!       WRITE(0,*)""
       IFAIL=12
       GOTO 11
      ENDIF

*   End of the external loop

      IF((MESTEST.GT.1d-12.AND.ITER.LT.10).OR.
     .   (MESTEST.GT.1d-8.AND.ITER.LT.50).OR.
     .   (MESTEST.GT.1d-6.AND.ITER.LT.100))GOTO 21
      IF(MESTEST.GT.1d-4)THEN
!       WRITE(0,*)"No convergence 2"
       IF(ITRY.LT.10)THEN
        ITRY=ITRY+1
!        WRITE(0,*)"ITRY=",ITRY
!        WRITE(0,*)""
!        WRITE(0,*)""
	ITER=0
        MST=0d0
        LT=0d0
        KT=0d0
        HTT=0d0
        JM=0
        GOTO 21
       ELSE
!        WRITE(0,*)"Exit (IFAIL=17)"
!        WRITE(0,*)""
!        WRITE(0,*)""
        IFAIL=17
        GOTO 11
       ENDIF
      ENDIF

*   Check if correct EWSB

      IF(DETM.LE.0d0 )THEN
!       WRITE(0,*)"Convergence in a false minimum"
       IF(ITRY.LT.10)THEN
        GOTO 1
       ELSE
!        WRITE(0,*)"Exit (IFAIL=20)"
!        WRITE(0,*)""
!        WRITE(0,*)""
        IFAIL=20
        GOTO 11
       ENDIF
      ENDIF

*  GUT scale

      CALL RGESGMGUT(PROB,IFAIL,GUTEST)
      IF(IFAIL.GT.0 .AND. GMFLAG.NE.0)THEN
!       WRITE(0,*)"RGE integration problem 4"
!       WRITE(0,*)"Exit (IFAIL=14)"
!       WRITE(0,*)""
!       WRITE(0,*)""
       IFAIL=14
       GOTO 11
      ELSE
       IFAIL=0
      ENDIF
      IF(GMFLAG.EQ.1)THEN
!       WRITE(0,*)"GUTEST =",GUTEST
!       WRITE(0,*)""
!       WRITE(0,*)""
       IF((GUTEST.GT.1d-12.AND.LOOP.LT.10).OR.
     .    (GUTEST.GT.1d-8.AND.LOOP.LT.50).OR.
     .    (GUTEST.GT.1d-6.AND.LOOP.LT.100))THEN
        CALL LPTSOLVE(IFAIL)
        IF(IFAIL.NE.0)THEN
!         WRITE(0,*)"RGE integration problem 5"
!         WRITE(0,*)"Exit (IFAIL=15)"
!         WRITE(0,*)""
!         WRITE(0,*)""
         IFAIL=15
         GOTO 11
        ENDIF
        GOTO 2
       ELSEIF(GUTEST.GT.1d-4)THEN
!        WRITE(0,*)"No convergence 3"
!        WRITE(0,*)"Exit (IFAIL=18)"
!        WRITE(0,*)""
!        WRITE(0,*)""
        IFAIL=18
        GOTO 11
       ENDIF
      ENDIF

*   Computation of sfermion masses

      CALL MSFERM(PAR,IFAIL,1)
      IF(IFAIL.NE.0)GOTO 11

*   Computation of Higgs masses

      CALL MHIGGS(PAR,IFAIL)
      IF(IFAIL.EQ.-1)IFAIL=19
      IF(IFAIL.NE.0)GOTO 11

*   Computation of gluino mass

      CALL GLUINO(PAR)

*   Computation of chargino masses

      CALL CHARGINO(PAR)

*   Computation of neutralino masses

      CALL NEUTRALINO(PAR)

*   Computation of Higgs + top branching ratios

      CALL DECAY(PAR)
      CALL TDECAY(PAR)

*   Exp. constraints on sparticles/Higgses

      CALL SUBEXP(PAR,PROB)
      CALL LHCHIG(PAR,PROB)
      CALL Higgs_CHI2(PAR,PROB)
      CALL CMS_TAUTAU(PAR,PROB)
      CALL CMS_AA_4MU(PAR,PROB)
      CALL ATLAS_H_GAMGAM(PROB)

*   b -> s gamma + B physics

      CALL BSG(PAR,PROB)

*   Anom. magn. moment of the Muon

      IF(GMUFLAG.EQ.1)CALL MAGNMU(PAR,PROB)

*   Global minimum?

      CALL CHECKMIN(PROB)

*   Computation of the fine-tuning

      CALL FTPAR(PAR,2)

*   Check for problems

c      DO I=1,NPROB
c       IF(PROB(I).NE.0d0)IFAIL=10
c      ENDDO

*   Sparticle decays

      M32=CGR*MSUSYEFF*MMESS/DSQRT(3d0)/MPL
      IF(NMSFLAG.NE.0)CALL NMSDECAY(PAR)

*   Check MSMES=MSREF if GMFLAG>0

      IF(GMFLAG.NE.0)THEN
       MSREF=MSUSYEFF**2/(4d0*PI)**4*(
     .      - 2d0*G1MES*LDMES**2 - 6d0*G2MES*LDMES**2
     .      + 6d0*HBMES*LDMES**2 + 2d0*HLMES*LDMES**2
     .      - 8d0*KMES**2*LDMES**2 + 8d0*LDMES**4 + 4d0*LDMES**2*LMES
     .      + 12d0*DSQRT(HBMES)*LBMES*LDMES*LPPMES
     .      + 4d0*DSQRT(HLMES)*LDMES*LLMES*LPPMES
     .      - 2d0*G1MES*LPPMES**2 - 6d0*G2MES*LPPMES**2
     .      - 8d0*KMES**2*LPPMES**2 + 6d0*LBMES**2*LPPMES**2
     .      + 16d0*LDMES**2*LPPMES**2 + 2d0*LLMES**2*LPPMES**2
     .      + 8d0*LPPMES**4 + 12d0*DSQRT(HTMES*LMES)*LDMES*LTMES
     .      + 6d0*LDMES**2*LTMES**2 + 6d0*LPPMES**2*LTMES**2
     .      - 4d0/3d0*G1MES*LTTMES**2 - 16d0*G3MES*LTTMES**2
     .      - 12d0*KMES**2*LTTMES**2 + 12d0*LDMES**2*LTTMES**2
     .      + 12d0*LPPMES**2*LTTMES**2 + 15d0*LTTMES**4
     .      + 12d0*DSQRT(HBMES*LMES)*LBMES*LUMES
     .      + 4d0*DSQRT(HLMES*LMES)*LLMES*LUMES
     .      + 16d0*LDMES*DSQRT(LMES)*LPPMES*LUMES
     .      + 12d0*DSQRT(HTMES)*LPPMES*LTMES*LUMES
     .      - 2d0*G1MES*LUMES**2 - 6d0*G2MES*LUMES**2
     .      + 6d0*HTMES*LUMES**2 - 8d0*KMES**2*LUMES**2
     .      + 6d0*LBMES**2*LUMES**2 + 8d0*LDMES**2*LUMES**2
     .      + 2d0*LLMES**2*LUMES**2 + 4d0*LMES*LUMES**2
     .      + 16d0*LPPMES**2*LUMES**2 + 12d0*LTTMES**2*LUMES**2
     .      + 8d0*LUMES**4)
     .      -MSUSYEFF**4/(48d0*PI**2*MMESS**2)
     .       *(2d0*LPPMES**2+3d0*LTTMES**2+LUMES**2+LDMES**2)
       D=(MSMES-MSREF)/(1d0+DABS(MSMES)+DABS(MSREF))
       IF(DABS(D).GT.DMIN)THEN
        IF(IFAIL.EQ.0)IFAIL=21
        IF(IFAIL.EQ.10)IFAIL=22
       ENDIF
!       WRITE(0,*)"MSREF =",MSREF
!       WRITE(0,*)"MSMES =",MSMES
!       WRITE(0,*)"D =",D
!       WRITE(0,*)""
!       WRITE(0,*)""
      ENDIF

*   Recording of the results

11    CALL MCMCSTEPGM(PAR,PROB,NPROB,IFAIL)
      CALL OUTPUT(PAR,PROB,IFAIL)
      IF(IFAIL.EQ.0)THEN
       TOT=TOT+1
       MSUSYEFFN=MIN(MSUSYEFF,MSUSYEFFN)
       MSUSYEFFNN=MAX(MSUSYEFF,MSUSYEFFNN)
       MMESSN=MIN(MMESS,MMESSN)
       MMESSNN=MAX(MMESS,MMESSNN)
       TBN=MIN(PAR(3),TBN)
       TBNN=MAX(PAR(3),TBNN)
       LN=MIN(PAR(1),LN)
       LNN=MAX(PAR(1),LNN)
       KN=MIN(PAR(2),KN)
       KNN=MAX(PAR(2),KNN)
       ALN=MIN(ALINP,ALN)
       ALNN=MAX(ALINP,ALNN)
       MUN=MIN(PAR(4),MUN)
       MUNN=MAX(PAR(4),MUNN)
       XIFN=MIN(XIFMES,XIFN)
       XIFNN=MAX(XIFMES,XIFNN)
       XISN=MIN(XISMES,XISN)
       XISNN=MAX(XISMES,XISNN)
       MSN=MIN(MSMES,MSN)
       MSNN=MAX(MSMES,MSNN)
       MUPN=MIN(MUPMES,MUPN)
       MUPNN=MAX(MUPMES,MUPNN)
       MSPN=MIN(MSPMES,MSPN)
       MSPNN=MAX(MSPMES,MSPNN)
       XIUN=MIN(XIU,XIUN)
       XIUNN=MAX(XIU,XIUNN)
       LPPN=MIN(LPPMES,LPPN)
       LPPNN=MAX(LPPMES,LPPNN)
       LTTN=MIN(LTTMES,LTTN)
       LTTNN=MAX(LTTMES,LTTNN)
       LUN=MIN(LUMES,LUN)
       LUNN=MAX(LUMES,LUNN)
       LDN=MIN(LDMES,LDN)
       LDNN=MAX(LDMES,LDNN)
       LTN=MIN(LTMES,LTN)
       LTNN=MAX(LTMES,LTNN)
       LBN=MIN(LBMES,LBN)
       LBNN=MAX(LBMES,LBNN)
       LLN=MIN(LLMES,LLN)
       LLNN=MAX(LLMES,LLNN)
      ELSE
       NFAIL(IFAIL)=NFAIL(IFAIL)+1
       IFAIL=0
      ENDIF

      IF(TOT.EQ.TOTMAX)THEN
       NTOT=ITOT
       GOTO 12
      ENDIF
      IF(IP.EQ.1)GOTO 13

      ENDDO

      IP=1
 13   IF(TOT.LT.TOTMIN .AND. NTOT.LT.NMAX)THEN
       NTOT=NTOT+1
       GOTO 14
      ENDIF

*   Summary of the scanning:
*   Number of points that passed/failed the tests
*   and range for scanned parameters

 12   CALL ERROR(TOT,NTOT,NFAIL)

      END


      SUBROUTINE INPUT(PAR,NPAR)

*******************************************************************
*   This subroutine reads SM and NMSSM parameters from input file   .
*******************************************************************

      IMPLICIT NONE

      CHARACTER CHINL*120,CHBLCK*60,CHDUM*120

      INTEGER I,NLINE,INL,ICH,IX,IVAL,Q2FIX,MCFLAG,TOTMIN,TOTMAX,NMAX
      INTEGER NTOT,ISEED,GMFLAG,N0,NLOOP,NBER,NPAR,ERR,VFLAG,NMSFLAG
      INTEGER OMGFLAG,MAFLAG,MOFLAG,PFLAG,GMUFLAG,HFLAG,Z3FLAG

      DOUBLE PRECISION PAR(*),VAL
      DOUBLE PRECISION ACC,XITLA,XLAMBDA,MC0,MB0,MT0
      DOUBLE PRECISION ALSMZ,ALEMMZ,GF,g1,g2,S2TW,M32,CGR,MPL
      DOUBLE PRECISION MS,MC,MB,MBP,MT,MTAU,MMUON,MZ,MW
      DOUBLE PRECISION VUS,VCB,VUB,Q2,SIGMU,Q2MIN
      DOUBLE PRECISION MSUSYEFFCEN,MSUSYEFFDEV,MMESSCEN,MMESSDEV
      DOUBLE PRECISION TBCEN,TBDEV,LCEN,LDEV,KCEN,KDEV,ALCEN,ALDEV
      DOUBLE PRECISION XIFCEN,XIFDEV,XISCEN,XISDEV,MUPCEN,MUPDEV
      DOUBLE PRECISION MSPCEN,MSPDEV,MSCEN,MSDEV,XIUCEN,XIUDEV
      DOUBLE PRECISION LPPCEN,LPPDEV,LTTCEN,LTTDEV,LUCEN,LUDEV
      DOUBLE PRECISION LDCEN,LDDEV, LTCEN,LTDEV,LBCEN,LBDEV
      DOUBLE PRECISION LLCEN,LLDEV,XCEN,XDEV,X
      DOUBLE PRECISION MSUSYEFFMIN,MMESSMIN,TBMIN,LMIN,KMIN,ALMIN
      DOUBLE PRECISION XIFMIN,XISMIN,MUPMIN,MSPMIN,MSMIN,XIUMIN
      DOUBLE PRECISION LPPMIN,LTTMIN,LUMIN,LDMIN,LTMIN,LBMIN,LLMIN
      DOUBLE PRECISION MSUSYEFF,MMESS,N5,MSREF,D,DMIN

      COMMON/GAUGE/ALSMZ,ALEMMZ,GF,g1,g2,S2TW
      COMMON/SMSPEC/MS,MC,MB,MBP,MT,MTAU,MMUON,MZ,MW
      COMMON/CKM/VUS,VCB,VUB
      COMMON/ALS/XLAMBDA,MC0,MB0,MT0,N0
      COMMON/RENSCALE/Q2
      COMMON/Q2FIX/Q2MIN,Q2FIX
      COMMON/SIGMU/SIGMU
      COMMON/MCMCPAR/MSUSYEFFCEN,MSUSYEFFDEV,MMESSCEN,MMESSDEV,
     . TBCEN,TBDEV,LCEN,LDEV,KCEN,KDEV,ALCEN,ALDEV,XIFCEN,
     . XIFDEV,XISCEN,XISDEV,MUPCEN,MUPDEV,MSPCEN,MSPDEV,
     . MSCEN,MSDEV,XIUCEN,XIUDEV,LPPCEN,LPPDEV,LTTCEN,LTTDEV,
     . LUCEN,LUDEV,LDCEN,LDDEV, LTCEN,LTDEV,LBCEN,LBDEV,
     . LLCEN,LLDEV,XCEN,XDEV,X,
     . MSUSYEFFMIN,MMESSMIN,TBMIN,LMIN,KMIN,ALMIN,
     . XIFMIN,XISMIN,MUPMIN,MSPMIN,MSMIN,XIUMIN,
     . LPPMIN,LTTMIN,LUMIN,LDMIN,LTMIN,LBMIN,LLMIN
      COMMON/STEPS/NTOT,ISEED,TOTMIN,TOTMAX,NMAX
      COMMON/MESCAL/MSUSYEFF,MMESS,N5
      COMMON/FLAGS/OMGFLAG,MAFLAG,MOFLAG
      COMMON/PFLAG/PFLAG
      COMMON/GMUFLAG/GMUFLAG,HFLAG
      COMMON/MCFLAG/MCFLAG
      COMMON/GMSCEN/MSREF,D,DMIN,GMFLAG
      COMMON/VFLAG/VFLAG
      COMMON/NMSFLAG/NMSFLAG
      COMMON/M32/M32,CGR,MPL

*   INITIALIZATION OF THE SUSY PARAMETERS
      DO I=1,NPAR
       PAR(I)=0d0
      ENDDO

*   INITIALIZATION OF THE SCANNING PARAMETERS
      N5=1d99
      SIGMU=1d99
      MSUSYEFFCEN=1d99
      MSUSYEFFDEV=1d99
      MMESSCEN=1d99
      MMESSDEV=1d99
      TBCEN=1d99
      TBDEV=1d99
      LCEN=1d99
      LDEV=1d99
      KCEN=1d99
      KDEV=1d99
      ALCEN=1d99
      ALDEV=1d99
      XIFCEN=1d99
      XIFDEV=1d99
      XISCEN=1d99
      XISDEV=1d99
      MUPCEN=0d0
      MUPDEV=1d99
      MSPCEN=0d0
      MSPDEV=1d99
      MSCEN=1d99
      MSDEV=1d99
      XIUCEN=0d0
      XIUDEV=1d99
      LPPCEN=0d0
      LPPDEV=1d99
      LTTCEN=0d0
      LTTDEV=1d99
      LUCEN=0d0
      LUDEV=1d99
      LDCEN=0d0
      LDDEV=1d99
      LTCEN=0d0
      LTDEV=1d99
      LBCEN=0d0
      LBDEV=1d99
      LLCEN=0d0
      LLDEV=1d99
      XCEN=1d99
      XDEV=1d0
      MSUSYEFFMIN=0d0
      MMESSMIN=0d0
      TBMIN=0d0
      LMIN=0d0
      KMIN=0d0
      ALMIN=0d0
      XIFMIN=0d0
      XISMIN=0d0
      MUPMIN=0d0
      MSPMIN=0d0
      MSMIN=0d0
      XIUMIN=0d0
      LPPMIN=0d0
      LTTMIN=0d0
      LUMIN=0d0
      LDMIN=0d0
      LTMIN=0d0
      LBMIN=0d0
      LLMIN=0d0
      DMIN=1d99
      NTOT=0
      TOTMIN=0
      TOTMAX=1000000
      CGR=1d0
      MPL=2.4d18

*   DEFAULT VALUES FOR FLAGS
      OMGFLAG=0
      PFLAG=0
      GMUFLAG=1
      HFLAG=0
      GMFLAG=0
      MCFLAG=0
      VFLAG=0
      NMSFLAG=0
      MOFLAG=0
      Z3FLAG=2

*   DEFAULT VALUE FOR THE RANDOM SEED
      ISEED=1

*   DEFAULT VALUE FOR THE RENSCALE Q2
      Q2=0d0

*   INITIALIZE READ LOOP
      NLINE=0
      CHBLCK=' '

*   START TO READ NEW LINE INTO CHINL
 21   CHINL=' '

*   LINE NUMBER
      NLINE=NLINE+1

      READ(5,'(A120)',END=29,ERR=999) CHINL

*   CHECK FOR EMPTY OR COMMENT LINES
      IF(CHINL.EQ.' '.OR.CHINL(1:1).EQ.'#'
     .  .OR.CHINL(1:1).EQ.'*') GOTO 21

*   FORCE UPPER CASE LETTERS IN CHINL (AS REQUIRED BELOW)
      INL=0
 22   INL=INL+1
      IF(CHINL(INL:INL).NE.'#')THEN
       DO ICH=97,122
        IF(CHINL(INL:INL).EQ.CHAR(ICH)) CHINL(INL:INL)=CHAR(ICH-32)
       END DO
       IF(INL.LT.120) GOTO 22
      ENDIF

*   CHECK FOR BLOCK STATEMENT
      IF(CHINL(1:1).EQ.'B')THEN
       READ(CHINL,'(A6,A)',ERR=999) CHDUM,CHBLCK
       GOTO 21
      ENDIF

*   CHECK FOR NMSSM MODEL IN MODSEL
*   IF THE RELIC DENSITY SHOULD BE COMPUTED
*   THE BLOCK MODSEL MUST CONTAIN THE LINE "  9     1    "
      IF(CHBLCK(1:6).EQ.'MODSEL')THEN
       READ(CHINL,*,ERR=999) IX,IVAL
       IF(IX.EQ.1) Z3FLAG=IVAL
       IF(IX.EQ.8) PFLAG=IVAL
       IF(IX.EQ.11) GMUFLAG=IVAL
       IF(IX.EQ.12) GMFLAG=IVAL
       IF(IX.EQ.13) NMSFLAG=IVAL
       IF(IX.EQ.14) VFLAG=IVAL

*   READ SMINPUTS
      ELSEIF(CHBLCK(1:8).EQ.'SMINPUTS')THEN
       READ(CHINL,*,ERR=999) IX,VAL
       IF(IX.EQ.2) GF=VAL
       IF(IX.EQ.3) ALSMZ=VAL
       IF(IX.EQ.4) MZ=VAL
       IF(IX.EQ.5) MB=VAL
       IF(IX.EQ.6) MT=VAL
       IF(IX.EQ.7) MTAU=VAL

*   READ MESS PARAMETERS, SIGMU, Q2 AND TANBETA
      ELSEIF(CHBLCK(1:6).EQ.'MINPAR')THEN
       READ(CHINL,*,ERR=999) IX,VAL
       IF(IX.EQ.0.AND.Q2.EQ.0D0) Q2=VAL**2
       IF(IX.EQ.1) MSUSYEFFCEN=VAL
       IF(IX.EQ.16) MSUSYEFFDEV=VAL
       IF(IX.EQ.17) MSUSYEFFMIN=VAL
       IF(IX.EQ.2) MMESSCEN=VAL
       IF(IX.EQ.26) MMESSDEV=VAL
       IF(IX.EQ.27) MMESSMIN=VAL
       IF(IX.EQ.3) TBCEN=VAL
       IF(IX.EQ.36) TBDEV=VAL
       IF(IX.EQ.37) TBMIN=VAL
       IF(IX.EQ.4)  SIGMU=VAL
       IF(IX.EQ.5)  N5=VAL
       IF(IX.EQ.6) CGR=VAL

*   READ EXTPAR
      ELSEIF(CHBLCK(1:6).EQ.'EXTPAR')THEN
       READ(CHINL,*,ERR=999) IX,VAL
       IF(IX.EQ.0) Q2=VAL**2
       IF(IX.EQ.-1) XDEV=VAL
       IF(IX.EQ.-2) DMIN=VAL
       IF(IX.EQ.61) LCEN=VAL
       IF(IX.EQ.616) LDEV=VAL
       IF(IX.EQ.617) LMIN=VAL
       IF(IX.EQ.62) KCEN=VAL
       IF(IX.EQ.626) KDEV=VAL
       IF(IX.EQ.627) KMIN=VAL
       IF(IX.EQ.63) ALCEN=VAL
       IF(IX.EQ.636) ALDEV=VAL
       IF(IX.EQ.637) ALMIN=VAL
       IF(IX.EQ.66) XIFCEN=VAL
       IF(IX.EQ.666) XIFDEV=VAL
       IF(IX.EQ.667) XIFMIN=VAL
       IF(IX.EQ.67) XISCEN=VAL
       IF(IX.EQ.676) XISDEV=VAL
       IF(IX.EQ.677) XISMIN=VAL
       IF(IX.EQ.68) MUPCEN=VAL
       IF(IX.EQ.686) MUPDEV=VAL
       IF(IX.EQ.687) MUPMIN=VAL
       IF(IX.EQ.69) MSPCEN=VAL
       IF(IX.EQ.696) MSPDEV=VAL
       IF(IX.EQ.697) MSPMIN=VAL
       IF(IX.EQ.70) MSCEN=VAL
       IF(IX.EQ.706) MSDEV=VAL
       IF(IX.EQ.707) MSMIN=VAL
       IF(IX.EQ.73) XIUCEN=VAL
       IF(IX.EQ.736) XIUDEV=VAL
       IF(IX.EQ.737) XIUMIN=VAL
       IF(IX.EQ.74) LPPCEN=VAL
       IF(IX.EQ.746) LPPDEV=VAL
       IF(IX.EQ.747) LPPMIN=VAL
       IF(IX.EQ.75) LTTCEN=VAL
       IF(IX.EQ.756) LTTDEV=VAL
       IF(IX.EQ.757) LTTMIN=VAL
       IF(IX.EQ.76) LUCEN=VAL
       IF(IX.EQ.766) LUDEV=VAL
       IF(IX.EQ.767) LUMIN=VAL
       IF(IX.EQ.77) LDCEN=VAL
       IF(IX.EQ.776) LDDEV=VAL
       IF(IX.EQ.777) LDMIN=VAL
       IF(IX.EQ.78) LTCEN=VAL
       IF(IX.EQ.786) LTDEV=VAL
       IF(IX.EQ.787) LTMIN=VAL
       IF(IX.EQ.79) LBCEN=VAL
       IF(IX.EQ.796) LBDEV=VAL
       IF(IX.EQ.797) LBMIN=VAL
       IF(IX.EQ.80) LLCEN=VAL
       IF(IX.EQ.806) LLDEV=VAL
       IF(IX.EQ.807) LLMIN=VAL

*   READ STEPS
       ELSEIF(CHBLCK(1:6).EQ.'STEPS')THEN
       READ(CHINL,*,ERR=999) IX,IVAL
       IF(IX.EQ.0) NTOT=IVAL
       IF(IX.EQ.1) ISEED=IVAL
       IF(IX.EQ.2) HFLAG=IVAL
       IF(IX.EQ.3) MCFLAG=IVAL
       IF(IX.EQ.4) TOTMIN=IVAL
       IF(IX.EQ.5) TOTMAX=IVAL
       IF(IX.EQ.6) NMAX=IVAL

      ENDIF

      GOTO 21

*   END OF READING FROM INPUT FILE

*   Check for errors

 29   ERR=0
      IF(GMFLAG.LT.0 .OR. GMFLAG.GT.2)THEN
       WRITE(0,1)"GMFLAG CAN BE 0, 1 OR 2"
       ERR=1
      ENDIF
      IF(XDEV.EQ.1d99)THEN
       WRITE(0,1)"XDEV MUST BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(MSUSYEFFCEN.EQ.1d99)THEN
       WRITE(0,1)"MSUSYEFFCEN MUST BE GIVEN IN BLOCK CENPAR"
       ERR=1
      ENDIF
      IF(MMESSCEN.EQ.1d99)THEN
       WRITE(0,1)"MMESSCEN MUST BE GIVEN IN BLOCK CENPAR"
       ERR=1
      ENDIF
      IF(TBCEN.EQ.1d99)THEN
       WRITE(0,1)"TBCEN MUST BE GIVEN IN BLOCK CENPAR"
       ERR=1
      ENDIF
      IF(DABS(SIGMU).NE.1d0)THEN
       WRITE(0,1)"SIGMU IS EITHER 1 OR -1 IN BLOCK CENPAR"
       ERR=1
      ENDIF
      IF(N5.EQ.1d99)THEN
       WRITE(0,1)"N5 MUST BE GIVEN IN BLOCK CENPAR"
       ERR=1
      ENDIF
      IF(N5.LE.0d0.OR. ANINT(N5).NE.N5)THEN
       WRITE(0,1)"N5 MUST BE A POSITIVE INTEGER IN BLOCK CENPAR"
       ERR=1
      ENDIF
      IF(CGR.LE.0d0)THEN
       WRITE(0,1)"CGR MUST BE POSITIVE IN BLOCK MINPAR"
       ERR=1
      ENDIF
      IF(LCEN.EQ.1d99)THEN
       WRITE(0,1)"LCEN MUST BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(ALCEN.EQ.1d99 .AND. ALDEV.NE.1d99)THEN
       WRITE(0,1)"ALCEN MUST BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(KCEN.EQ.1d99 .AND. KDEV.NE.1d99)THEN
       WRITE(0,1)"KCEN MUST BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(XIFCEN.EQ.1d99 .AND. XIFDEV.NE.1d99)THEN
       WRITE(0,1)"XIFCEN MUST BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(XISCEN.EQ.1d99 .AND. XISDEV.NE.1d99)THEN
       WRITE(0,1)"XISCEN MUST BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(MSCEN.EQ.1d99 .AND. MSDEV.NE.1d99)THEN
       WRITE(0,1)"MSCEN MUST BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(XIFCEN.NE.1d99 .AND. KCEN.NE.1d99)THEN
       WRITE(0,1)"BOTH XIF AND KAPPA CANNOT BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(XISCEN.NE.1d99 .AND. MSCEN.NE.1d99)THEN
       WRITE(0,1)"BOTH XIS AND MS^2 CANNOT BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(GMFLAG.NE.0 .AND. KCEN.NE.1d99)THEN
       WRITE(0,1)"GMFLAG=/=0 => KCEN CANNOT BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(GMFLAG.NE.0 .AND. ALCEN.NE.1d99)THEN
       WRITE(0,1)"GMFLAG=/=0 => ALCEN CANNOT BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(GMFLAG.NE.0 .AND. MSCEN.NE.1d99)THEN
       WRITE(0,1)"GMFLAG=/=0 => MSCEN CANNOT BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(GMFLAG.NE.0 .AND. XIFCEN.NE.1d99)THEN
       WRITE(0,1)"GMFLAG=/=0 => XIFCEN CANNOT BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(GMFLAG.NE.0 .AND. XISCEN.NE.1d99)THEN
       WRITE(0,1)"GMFLAG=/=0 => XISCEN CANNOT BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(GMFLAG.EQ.0 .AND. DMIN.NE.1d99)THEN
       WRITE(0,1)"GMFLAG=0 => DMIN CANNOT BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(GMFLAG.NE.0 .AND. DMIN.EQ.1d99)THEN
       WRITE(0,1)"GMFLAG=/=0 => DMIN MUST BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(GMFLAG.NE.1 .AND. (XIUCEN.NE.0d0 .OR. XIUDEV.NE.1d99))THEN
       WRITE(0,1)"GMFLAG=/=1 => XIU CANNOT BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(GMFLAG.NE.2 .AND. (LPPCEN.NE.0d0 .OR. LPPDEV.NE.1d99))THEN
       WRITE(0,1)"GMFLAG=/=2 => LPP CANNOT BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(GMFLAG.NE.2 .AND. (LTTCEN.NE.0d0 .OR. LTTDEV.NE.1d99))THEN
       WRITE(0,1)"GMFLAG=/=2 => LTT CANNOT BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(GMFLAG.EQ.0 .AND. (LUCEN.NE.0d0 .OR. LUDEV.NE.1d99))THEN
       WRITE(0,1)"GMFLAG=/=1,2 => LU CANNOT BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(GMFLAG.EQ.0 .AND. (LDCEN.NE.0d0 .OR. LDDEV.NE.1d99))THEN
       WRITE(0,1)"GMFLAG=/=1,2 => LD CANNOT BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(GMFLAG.EQ.0 .AND. (LTCEN.NE.0d0 .OR. LTDEV.NE.1d99))THEN
       WRITE(0,1)"GMFLAG=/=1,2 => LT CANNOT BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(GMFLAG.EQ.0 .AND. (LBCEN.NE.0d0 .OR. LBDEV.NE.1d99))THEN
       WRITE(0,1)"GMFLAG=/=1,2 => LB CANNOT BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF
      IF(GMFLAG.EQ.0 .AND. (LLCEN.NE.0d0 .OR. LLDEV.NE.1d99))THEN
       WRITE(0,1)"GMFLAG=/=1,2 => LL CANNOT BE GIVEN IN BLOCK EXTPAR"
       ERR=1
      ENDIF

*   Set default values

      IF(KCEN.EQ.1d99 .AND. XIFCEN.EQ.1d99)XIFCEN=0d0
      IF(MSCEN.EQ.1d99 .AND. XISCEN.EQ.1d99)XISCEN=0d0
      IF(ALCEN.EQ.1d99)ALCEN=0d0

      IF(MSUSYEFFDEV.EQ.1d99)MSUSYEFFDEV=0d0
      IF(MMESSDEV.EQ.1d99)MMESSDEV=0d0
      IF(TBDEV.EQ.1d99)TBDEV=0d0
      IF(LDEV.EQ.1d99)LDEV=0d0
      IF(KDEV.EQ.1d99)KDEV=0d0
      IF(ALDEV.EQ.1d99)ALDEV=0d0
      IF(XIFDEV.EQ.1d99)XIFDEV=0d0
      IF(XISDEV.EQ.1d99)XISDEV=0d0
      IF(MUPDEV.EQ.1d99)MUPDEV=0d0
      IF(MSPDEV.EQ.1d99)MSPDEV=0d0
      IF(MSDEV.EQ.1d99)MSDEV=0d0
      IF(XIUDEV.EQ.1d99)XIUDEV=0d0
      IF(LPPDEV.EQ.1d99)LPPDEV=0d0
      IF(LTTDEV.EQ.1d99)LTTDEV=0d0
      IF(LUDEV.EQ.1d99)LUDEV=0d0
      IF(LDDEV.EQ.1d99)LDDEV=0d0
      IF(LTDEV.EQ.1d99)LTDEV=0d0
      IF(LBDEV.EQ.1d99)LBDEV=0d0
      IF(LLDEV.EQ.1d99)LLDEV=0d0


*   Set MAFLAG

      IF(KCEN.EQ.1d99 .AND. MSCEN.EQ.1d99)MAFLAG=-1
      IF(KCEN.EQ.1d99 .AND. XISCEN.EQ.1d99)MAFLAG=-2
      IF(XIFCEN.EQ.1d99 .AND. MSCEN.EQ.1d99)MAFLAG=-3
      IF(XIFCEN.EQ.1d99 .AND. XISCEN.EQ.1d99)MAFLAG=-4
      NMSFLAG=2*NMSFLAG

*   Total number of points

      IF(NTOT.LE.0)THEN
       WRITE(0,1)"WRONG NUMBER OF POINTS IN BLOCK STEPS"
       ERR=1
      ENDIF
      IF(TOTMIN.GT.TOTMAX)THEN
       WRITE(0,1)"TOTMIN must be smaller than TOTMAX"
       ERR=1
      ENDIF

*   Check for Z3 breaking terms

      IF(MAFLAG.EQ.-2 .OR. MAFLAG.EQ.-3 .OR. MAFLAG.EQ.-4 .OR.
     . MUPCEN.NE.0d0 .OR. MUPDEV.NE.0d0 .OR. MSPCEN.NE.0d0 .OR. 
     . MSPDEV.NE.0d0 .OR. XIFCEN.NE.0d0 .OR. XIFDEV.NE.0d0 .OR.
     . XISCEN.NE.0d0 .OR. XISDEV.NE.0d0)THEN
       IF(PFLAG.NE.0)THEN
        WRITE(0,1)"HIGGS MASS PRECISION = 1 OR 2 ONLY FOR Z3-NMSSM"
        ERR=1
       ENDIF
       IF(Z3FLAG.GT.2)THEN
        WRITE(0,1)"PRESENCE OF Z3 BREAKING TERMS"
        ERR=1
       ENDIF
      ENDIF

*   Stop if error

      IF(ERR.EQ.1)THEN
       WRITE(0,1)"ERROR IN INPUT FILE"
       STOP 1
      ENDIF

*   Set Q2MIN, Q2FIX:
      Q2MIN=100d0**2
      Q2FIX=1
      IF(Q2.LE.Q2MIN)THEN
       Q2FIX=0
      ENDIF

*   Initialization for ALPHAS and RUNM (as in hdecay)
*   The bottom quark pole mass MBP is set in INIT and can be changed
*   only there (changing its running mass MB above has no effect
*   on MBP, since one would have to compute alpha_s(MB) first)

      MC0=MC
      MB0=MBP
      MT0=MT
      N0=5
      NLOOP=2
      NBER=18
      ACC=1d-8
      XLAMBDA=XITLA(NLOOP,ALSMZ,ACC)
      CALL ALSINI(ACC)
      CALL BERNINI(NBER)

*    g1,g2  and sin(theta)^2 in the on-shell scheme in terms of
*    GF, MZ(pole) and MW(pole)

      g2=4d0*DSQRT(2d0)*GF*MW**2
      g1=4d0*DSQRT(2d0)*GF*(MZ**2-MW**2)
      S2TW=1d0-(MW/MZ)**2

      RETURN

 999  WRITE(0,1)"READ ERROR ON LINE:", NLINE
      WRITE(0,*)CHINL(1:80)
      STOP 1

 1    FORMAT(A)

      END


      SUBROUTINE OUTPUT(PAR,PROB,IFAIL)

*********************************************************************
*   Subroutine writing all the results in the the output file.
*********************************************************************

      IMPLICIT NONE

      INTEGER GMFLAG,I,J,NRES,IRES,NSUSY,NGUT,NMES,IMAX,IFAIL
      PARAMETER (NSUSY=14,NGUT=21,NMES=20,IMAX=200)

      DOUBLE PRECISION RES(IMAX),PAR(*),PROB(*),SIG(3,10)
      DOUBLE PRECISION SMASS(3),PMASS(2),CMASS,SCOMP(3,3),PCOMP(2,2)
      DOUBLE PRECISION MGL,MCHA(2),U(2,2),V(2,2),MNEU(5),NEU(5,5)
      DOUBLE PRECISION BRJJ(5),BREE(5),BRMM(5),BRLL(5),BRSS(5)
      DOUBLE PRECISION BRCC(5),BRBB(5),BRTT(5),BRWW(3),BRZZ(3)
      DOUBLE PRECISION BRGG(5),BRZG(5),BRHHH(4),BRHAA(3,3)
      DOUBLE PRECISION BRHCHC(3),BRHAZ(3,2),BRAHA(3),BRAHZ(2,3)
      DOUBLE PRECISION BRHCW(5),BRHIGGS(5),BRNEU(5,5,5),BRCHA(5,3)
      DOUBLE PRECISION BRHSQ(3,10),BRHSL(3,7),BRASQ(2,2),BRASL(2)
      DOUBLE PRECISION BRSUSY(5),WIDTH(5)
      DOUBLE PRECISION HCBRM,HCBRL,HCBRSU,HCBRBU,HCBRSC,HCBRBC
      DOUBLE PRECISION HCBRBT,HCBRWH(5),HCBRWHT,HCBRNC(5,2)
      DOUBLE PRECISION HCBRSQ(5),HCBRSL(3),HCBRSUSY,HCWIDTH
      DOUBLE PRECISION CU(5),CD(5),CV(3),CJ(5),CG(5),CB(5)
      DOUBLE PRECISION ALSMZ,ALEMMZ,GF,g1,g2,S2TW
      DOUBLE PRECISION MS,MC,MB,MBP,MT,MTAU,MMUON,MZ,MW
      DOUBLE PRECISION VUS,VCB,VUB,MSREF,D,DMIN
      DOUBLE PRECISION MUR,MUL,MDR,MDL,MLR,MLL,MNL
      DOUBLE PRECISION MST1,MST2,MSB1,MSB2,MSL1,MSL2,MSNT
      DOUBLE PRECISION CST,CSB,CSL,MSMU1,MSMU2,MSNM,CSMU,Q2
      DOUBLE PRECISION RMST1,RMST2,S2T,RMSB1,RMSB2,S2B,XT,XB
      DOUBLE PRECISION g1s,g2s,g3s,HTOPS,HBOTS,HTAUS
      DOUBLE PRECISION MHUS,MHDS,MSS,M32,CGR,MPL
      DOUBLE PRECISION G1MES,G2MES,G3MES,LMES,KMES,HTMES,HBMES,HLMES
      DOUBLE PRECISION LPPMES,LTTMES,LUMES,LDMES,LTMES,LBMES,LLMES,XIU
      DOUBLE PRECISION LPPGUT,LTTGUT,LUGUT,LDGUT,LTGUT,LBGUT,LLGUT
      DOUBLE PRECISION SIGMU,MGUT
      DOUBLE PRECISION MHUQ,MHDQ,MSQ,LQ,KQ,ALQ,AKQ,MUQ,NUQ
      DOUBLE PRECISION ZHU,ZHD,ZS,H1Q,H2Q,TANBQ,QSTSB
      DOUBLE PRECISION BRSG,BRSGmax,BRSGmin,DMd,DMdmin,DMdmax,DMs,
     . DMsmax,DMsmin,BRBMUMU,BRBMUMUmax,BRBMUMUmin,BRBtaunu,
     . BRBtaunumax,BRBtaunumin
      DOUBLE PRECISION delmagmu,damumin,damumax,amuthmax,amuthmin
      DOUBLE PRECISION MSUSYEFF,MMESS,N5
      DOUBLE PRECISION M1MES,M2MES,M3MES,ALMES,AKMES,ATMES,ABMES,
     . ATAUMES,AMUMES,MHUMES,MHDMES,MQ3MES,MU3MES,MD3MES,
     . MQMES,MUMES,MDMES,ML3MES,ME3MES,MLMES,MEMES
      DOUBLE PRECISION XIFMES,XISMES,MSMES,MUPMES,MSPMES,M3HMES
      DOUBLE PRECISION XIFSUSY,XISSUSY,MUPSUSY,MSPSUSY,M3HSUSY
      DOUBLE PRECISION ALINP,XIFINP,XISINP,MSINP,MUPINP,MSPINP
      DOUBLE PRECISION G1GUT,G2GUT,G3GUT,LGUT,KGUT,HTGUT,HBGUT,HLGUT
      DOUBLE PRECISION brtopbw,brtopbh,brtopneutrstop(5,2),toptot
      DOUBLE PRECISION FTSUSY(NSUSY+2),FTGUT(NGUT+2),FTMES(NMES+2)
      DOUBLE PRECISION DELMB,PX,PA(6),PB(2),PL(7),PK(8),MH(3),MMH(3)
      DOUBLE PRECISION DMH(3),MA(2),MMA(2),DMA(2),MHC,MMHC,DMHC
      DOUBLE PRECISION MHmin,MHmax,chi2max,chi2gam,chi2bb,chi2zz
*
      DOUBLE PRECISION chartot2(2),chartot(2),chartot3(2)
      DOUBLE PRECISION brcharsel(2),brcharser(2),brcharsmu1(2),
     .         brcharsmu2(2),brcharstau1(2),brcharstau2(2),
     .         brcharsne1(2),brcharsne2(2),brcharsnm1(2),brcharsnm2(2),
     .         brcharsnt1(2),brcharsnt2(2),brcharsupl(2),brcharsupr(2),
     .         brcharsdownl(2),brcharsdownr(2),brcharst1(2),
     .         brcharst2(2),brcharsb1(2),brcharsb2(2),brcharwneut(2,5),
     .         brcharhcneut(2,5),brcharzchic,brcharHchic(3),
     .         brcharAchic(2),brntaunut(2,5),brnelnue(2,5),
     .         brnmunumu(2,5),brnupdb(2,5),brnchsb(2,5),brntopbb(2,5),
     .         brglupdb(2),brglchsb(2),brgltopbb(2),brchee,brchmumu,
     .         brchtautau,brchnene,brchnmunmu,brchntauntau,brchupup,
     .         brchdodo,brchchch,brchstst,brchtoptop,brchbotbot
*
      DOUBLE PRECISION neuttot2(5),neuttot(5),neuttot3(5),neuttotrad(5)
      DOUBLE PRECISION brneutst1(5),brneutst2(5),brneutsb1(5),
     .         brneutsb2(5),
     .         brneutsupl(5),brneutsupr(5),brneutsdownl(5),
     .         brneutsdownr(5),brneutsnel(5),brneutsn1(5),
     .         brneutsn2(5),brneutsell(5),brneutselr(5),
     .         brneutsnmu(5),brneutsmu1(5),brneutsmu2(5),
     .         brneutstau1(5),brneutstau2(5),brneutwchar(5,2),
     .         brneuthcchar(5,2),brneutzneut(5,5),
     .         brneutHneut(5,5,3),brneutAneut(5,5,2),brnraddec(5,5)
      DOUBLE PRECISION brneutup(5,5),brneutdow(5,5),brneutch(5,5),
     .         brneutst(5,5),brneutbot(5,5),brneuttop(5,5),
     .         brneutel(5,5),brneutmu(5,5),brneuttau(5,5),
     .         brneutnue(5,5),brneutnumu(5,5),brneutnutau(5,5),
     .         brchubd(5,2),brchcbs(5,2),brchtbb(5,2),brchelne(5,2),
     .         brchmunmu(5,2),brchtauntau(5,2),brglup(5),brgldo(5),
     .         brglch(5),brglst(5),brgltop(5),brglbot(5)
*
      DOUBLE PRECISION selltot,selltot2,selltot3,selrtot,selrtot2,
     .         selrtot3,smu1tot,smu1tot2,smu1tot3,smu2tot,smu2tot2,
     .         smu2tot3,stau1tot2,stau2tot,stau2tot2,stau2tot3,
     .         snelltot,snelltot2,snelltot3,snmu1tot,snmu1tot2,
     .         snmu1tot3,sntautot,sntautot2,sntautot3
      DOUBLE PRECISION brsellneute(5),brselrneute(5),brsellcharnue(2),
     .         brselrcharnue(2),brsnellneut(5),brsnellchar(5),
     .         brsmu1neutmu(5),brsmu2neutmu(5),brsmu1charnumu(2),
     .         brsmu2charnumu(2),brsnmu1neut(5),brsnmu1char(5),
     .         brstau1neut(5),brstau2neut(5),brstau1char(2),
     .         brstau2char(2),brstau1hcsn(2),brstau2hcsn(2),
     .         brstau1wsn(2),brstau2wsn(2),brstau2ztau,brstau2H(3),
     .         brstau2A(2),brsntauneut(5),brsntauchar(2),
     .         brsntau1hcstau(2),brsntau1wstau(2)
      DOUBLE PRECISION brsellstau1star,brsellstau1,
     .         brsellstau1nutau,brselrstau1star,brselrstau1,
     .         brselrstau1nutau,brsnestau1star,brsnestau1,
     .         brsnestau1nutau,brsmu1stau1star,brsmu1stau1,
     .         brsmu1stau1nutau,brsmu2stau1star,brsmu2stau1,
     .         brsmu2stau1nutau,brsnmustau1star,brsnmustau1,
     .         brsnmustau1nutau,brstau2stau1star,brstau2stau1,
     .         brstau2stau1nn,brsntaustau1star,brsntaustau1,
     .         brsntaustau1nutau
*
      DOUBLE PRECISION supltot2,suprtot2,sdowltot2,sdowrtot2
      DOUBLE PRECISION brsuplnup(5),brsuplcdow(2),brsuplglui,
     .         brsuprnup(5),brsuprcdow(2),brsuprglui,
     .         brsdowlndow(5),brsdowlchup(2),brsdowlglui,
     .         brsdowrndow(5),brsdowrchup(2),brsdowrglui
*
      DOUBLE PRECISION stoptot(2),stoptot2(2),stoptot3(2),stoptotrad(2)
      DOUBLE PRECISION brst1neutt(5),brst2neutt(5),brst1charb(2),
     .         brst2charb(2),brst1hcsb(2),brst2hcsb(2),brst1wsb(2),
     .         brst2wsb(2),brst1glui,brst2glui,brst2H(3),brst2A(2),
     .         brst2ztop,brgamma,brgammaup,brgammagluino
      DOUBLE PRECISION brstopw(2,5),brstoph(2,5),brststau(2,2),
     .         brstsntau(2,2),brstsmu(2,2),brstsnmu(2),brstsel(2,2),
     .         brstsnel(2),brstbsbst(2,2),brstbbsbt(2,2),
     .         brsttausbnu(2,2),brstelsbnu(2,2),brstupsbdow(2,2),
     .         brst2st1tt,brst2st1startt,brst2st1bb,brst2st1uu,
     .         brst2st1dd,brst2st1ee,brst2st1nunu,brst2st1tautau
*
      DOUBLE PRECISION sbottot(2),sbottot2(2),sbottot3(2)
      DOUBLE PRECISION brsb1neutt(5),brsb2neutt(5),brsb1chart(2),
     .         brsb2chart(2),brsb1hcst(2),brsb2hcst(2),
     .         brsb1glui,brsb2glui,brsb1wst(2),
     .         brsb2wst(2),brsb2H(3),brsb2A(2),brsb2zbot
      DOUBLE PRECISION  brsbstau(2,2),brsbsntau(2,2),brsbsel(2,2),
     .         brsbtstsb(2,2),brsbtbstb(2,2),brsbtaustnu(2,2),
     .         brsbelstnu(2,2),brsbupstdow(2,2),brsbsnel(2),
     .         brsb2sb1bb,brsb2sb1starbb,brsb2sb1tt,
     .         brsb2sb1uu,brsb2sb1dd,brsb2sb1ee,brsb2sb1nunu,
     .         brsb2sb1tautau,brsbsmu(2,2),brsbsnmu(2)
*
      DOUBLE PRECISION gluitot,gluitot2,gluitot3,gluitotrad
      DOUBLE PRECISION brgst1,brgst2,brgsb1,brgsb2,brgsupl,brgsupr,
     .         brgsdownl,brgsdownr,brglnjgluon(5)
      DOUBLE PRECISION brgoup(5),brgoch(5),brgodn(5),brgost(5),
     .         brgotp(5),brgobt(5),brgoud(2),brgocs(2),brgotb(2),
     .         brhcst1b,brwst1b
*
      DOUBLE PRECISION brcharWgra(2),brcharHCgra(2),brneutGAMgra(5),
     .         brneutZgra(5),brneutHgra(5,3),brneutAgra(5,2),
     .         brgluiGLUgra,brselEgra,brserEgra,brsmu1MUgra,
     .         brsmu2MUgra,brstau1TAUgra,brstau2TAUgra,brsneNEgra,
     .         brsnmNMgra,brsntNTgra,brsulUgra,brsurUgra,brsdlDgra,
     .         brsdrDgra,brst1Tgra,brst2Tgra,brsb1Bgra,brsb2Bgra
*
      COMMON/CHARGINO_WIDTH/chartot2,chartot,chartot3
      COMMON/CHARGINO_BR_2BD/brcharsel,brcharser,brcharsmu1,
     .         brcharsmu2,brcharstau1,brcharstau2,
     .         brcharsne1,brcharsne2,brcharsnm1,brcharsnm2,
     .         brcharsnt1,brcharsnt2,brcharsupl,brcharsupr,
     .         brcharsdownl,brcharsdownr,brcharst1,
     .         brcharst2,brcharsb1,brcharsb2,brcharwneut,
     .         brcharhcneut,brcharzchic,brcharHchic,
     .         brcharAchic
      COMMON/CHARGINO_BR_3BD/brntaunut,brnelnue,brnmunumu,
     .         brnupdb,brnchsb,brntopbb,
     .         brglupdb,brglchsb,brgltopbb,
     .         brchee,brchmumu,brchtautau,brchnene,
     .         brchnmunmu,brchntauntau,brchupup,brchdodo,
     .         brchchch,brchstst,brchtoptop,brchbotbot
*
      COMMON/NEUTRALINO_WIDTH/neuttot2,neuttot,neuttot3,neuttotrad
      COMMON/NEUTRALINO_BR_2BD/brneutst1,brneutst2,brneutsb1,brneutsb2,
     .         brneutsupl,brneutsupr,brneutsdownl,brneutsdownr,
     .         brneutsnel,brneutsn1,brneutsn2,brneutsell,brneutselr,
     .         brneutsnmu,brneutsmu1,brneutsmu2,
     .         brneutstau1,brneutstau2,brneutwchar,brneuthcchar,
     .         brneutzneut,brneutHneut,brneutAneut,brnraddec
      COMMON/NEUTRALINO_BR_3BD/brneutup,brneutdow,brneutch,brneutst,
     .         brneutbot,brneuttop,brneutel,brneutmu,brneuttau,
     .         brneutnue,brneutnumu,brneutnutau,brchubd,brchcbs,
     .         brchtbb,brchelne,brchmunmu,brchtauntau,brglup,brgldo,
     .         brglch,brglst,brgltop,brglbot
*
      COMMON/SLEPTON_WIDTH/selltot,selltot2,selltot3,selrtot,
     .         selrtot2,selrtot3,smu1tot,smu1tot2,smu1tot3,smu2tot,
     .         smu2tot2,smu2tot3,stau1tot2,stau2tot,stau2tot2,
     .         stau2tot3,snelltot,snelltot2,snelltot3,snmu1tot,
     .         snmu1tot2,snmu1tot3,sntautot2,sntautot3,sntautot
      COMMON/SLEPTON_BR_2BD/brsellneute,brselrneute,brsellcharnue,
     .         brselrcharnue,brsnellneut,brsnellchar,brsmu1neutmu,
     .         brsmu2neutmu,brsmu1charnumu,brsmu2charnumu,brsnmu1neut,
     .         brsnmu1char,brstau1neut,brstau2neut,brstau1char,
     .         brstau2char,brstau1hcsn,brstau2hcsn,brstau1wsn,
     .         brstau2wsn,brstau2ztau,brstau2H,brstau2A,brsntauneut,
     .         brsntauchar,brsntau1hcstau,brsntau1wstau
      COMMON/SLEPTON_BR_3BD/brsellstau1star,brsellstau1,
     .         brsellstau1nutau,brselrstau1star,brselrstau1,
     .         brselrstau1nutau,brsnestau1star,brsnestau1,
     .         brsnestau1nutau,brsmu1stau1star,brsmu1stau1,
     .         brsmu1stau1nutau,brsmu2stau1star,brsmu2stau1,
     .         brsmu2stau1nutau,brsnmustau1star,brsnmustau1,
     .         brsnmustau1nutau,brstau2stau1star,brstau2stau1,
     .         brstau2stau1nn,brsntaustau1star,brsntaustau1,
     .         brsntaustau1nutau
*
      COMMON/SQUARK_WIDTH/supltot2,suprtot2,sdowltot2,sdowrtot2
      COMMON/SQUARK_BR_2BD/brsuplnup,brsuplcdow,brsuplglui,
     .         brsuprnup,brsuprcdow,brsuprglui,
     .         brsdowlndow,brsdowlchup,brsdowlglui,
     .         brsdowrndow,brsdowrchup,brsdowrglui
*
      COMMON/STOP_WIDTH/stoptot,stoptot2,stoptot3,stoptotrad
      COMMON/STOP_BR_2BD/brst1neutt,brst2neutt,brst1charb,
     .         brst2charb,brst1hcsb,brst2hcsb,brst1wsb,
     .         brst2wsb,brst1glui,brst2glui,brst2H,brst2A,
     .         brst2ztop,brgamma,brgammaup,brgammagluino
      COMMON/STOP_BR_3BD/brstopw,brstoph,brststau,
     .         brstsntau,brstsmu,brstsnmu,brstsel,
     .         brstsnel,brstbsbst,brstbbsbt,
     .         brsttausbnu,brstelsbnu,brstupsbdow,
     .         brst2st1tt,brst2st1startt,brst2st1bb,brst2st1uu,
     .         brst2st1dd,brst2st1ee,brst2st1nunu,brst2st1tautau
*
      COMMON/SBOTTOM_WIDTH/sbottot,sbottot2,sbottot3
      COMMON/SBOTTOM_BR_2BD/brsb1neutt,brsb2neutt,brsb1chart,
     .         brsb2chart,brsb1hcst,brsb2hcst,
     .         brsb1glui,brsb2glui,brsb1wst,
     .         brsb2wst,brsb2H,brsb2A,brsb2zbot
      COMMON/SBOTTOM_BR_3BD/brsbstau,brsbsntau,brsbsel,
     .         brsbtstsb,brsbtbstb,brsbtaustnu,
     .         brsbelstnu,brsbupstdow,brsbsnel,
     .         brsb2sb1bb,brsb2sb1starbb,brsb2sb1tt,
     .         brsb2sb1uu,brsb2sb1dd,brsb2sb1ee,brsb2sb1nunu,
     .         brsb2sb1tautau,brsbsmu,brsbsnmu
*
      COMMON/GLUINO_WIDTH/gluitot,gluitot2,gluitot3,gluitotrad
      COMMON/GLUINO_BR_2BD/brgst1,brgst2,brgsb1,brgsb2,brgsupl,brgsupr,
     .         brgsdownl,brgsdownr,brglnjgluon
      COMMON/GLUINO_BR_3BD/brgoup,brgoch,brgodn,brgost,brgotp,
     .         brgobt,brgoud,brgocs,brgotb,brhcst1b,brwst1b
*
      COMMON/GRAVITINO/brcharWgra,brcharHCgra,brneutGAMgra,
     .         brneutZgra,brneutHgra,brneutAgra,
     .         brgluiGLUgra,brselEgra,brserEgra,brsmu1MUgra,
     .         brsmu2MUgra,brstau1TAUgra,brstau2TAUgra,brsneNEgra,
     .         brsnmNMgra,brsntNTgra,brsulUgra,brsurUgra,brsdlDgra,
     .         brsdrDgra,brst1Tgra,brst2Tgra,brsb1Bgra,brsb2Bgra
*
      COMMON/SIGMU/SIGMU
      COMMON/INPPAR/ALINP,XIFINP,XISINP,MSINP,MUPINP,MSPINP
      COMMON/MESCAL/MSUSYEFF,MMESS,N5
      COMMON/MESEXT/XIFMES,XISMES,MSMES,MUPMES,MSPMES,M3HMES
      COMMON/SUSYEXT/XIFSUSY,XISSUSY,MUPSUSY,MSPSUSY,M3HSUSY
      COMMON/SOFTMES/M1MES,M2MES,M3MES,ALMES,AKMES,ATMES,ABMES,
     . ATAUMES,AMUMES,MHUMES,MHDMES,MQ3MES,MU3MES,MD3MES,
     . MQMES,MUMES,MDMES,ML3MES,ME3MES,MLMES,MEMES
      COMMON/BRN/BRJJ,BREE,BRMM,BRLL,BRSS,BRCC,BRBB,BRTT,BRWW,
     . BRZZ,BRGG,BRZG,BRHHH,BRHAA,BRHCHC,BRHAZ,BRAHA,BRAHZ,
     . BRHCW,BRHIGGS,BRNEU,BRCHA,BRHSQ,BRHSL,BRASQ,BRASL,
     . BRSUSY,WIDTH
      COMMON/BRC/HCBRM,HCBRL,HCBRSU,HCBRBU,HCBRSC,HCBRBC,
     . HCBRBT,HCBRWH,HCBRWHT,HCBRNC,HCBRSQ,HCBRSL,
     . HCBRSUSY,HCWIDTH
      COMMON/BRSG/BRSG,BRSGmax,BRSGmin,DMd,DMdmin,DMdmax,DMs,
     . DMsmax,DMsmin,BRBMUMU,BRBMUMUmax,BRBMUMUmin,BRBtaunu,
     . BRBtaunumax,BRBtaunumin
      COMMON/MAGMU/delmagmu,damumin,damumax,amuthmax,amuthmin
      COMMON/BR_top2body/brtopbw,brtopbh,brtopneutrstop
      COMMON/topwidth/toptot
      COMMON/REDCOUP/CU,CD,CV,CJ,CG
      COMMON/CB/CB
      COMMON/HIGGSPEC/SMASS,SCOMP,PMASS,PCOMP,CMASS
      COMMON/SUSYSPEC/MGL,MCHA,U,V,MNEU,NEU
      COMMON/GAUGE/ALSMZ,ALEMMZ,GF,g1,g2,S2TW
      COMMON/SMSPEC/MS,MC,MB,MBP,MT,MTAU,MMUON,MZ,MW
      COMMON/CKM/VUS,VCB,VUB
      COMMON/SFSPEC/MUR,MUL,MDR,MDL,MLR,MLL,MNL,
     . MST1,MST2,MSB1,MSB2,MSL1,MSL2,MSNT,
     . CST,CSB,CSL,MSMU1,MSMU2,MSNM,CSMU
      COMMON/RENSCALE/Q2
      COMMON/STSBSCALE/QSTSB
      COMMON/SUSYCOUP/g1s,g2s,g3s,HTOPS,HBOTS,HTAUS
      COMMON/SUSYMH/MHUS,MHDS,MSS
      COMMON/QMHIGGS/MHUQ,MHDQ,MSQ
      COMMON/QHIGGS/ZHU,ZHD,ZS,H1Q,H2Q,TANBQ
      COMMON/QPAR/LQ,KQ,ALQ,AKQ,MUQ,NUQ
      COMMON/MESCOUP/G1MES,G2MES,G3MES,LMES,KMES,HTMES,HBMES,HLMES
      COMMON/MESGUT/LPPMES,LTTMES,LUMES,LDMES,LTMES,LBMES,LLMES,XIU
      COMMON/GUTCOUP/G1GUT,G2GUT,G3GUT,LGUT,KGUT,HTGUT,HBGUT,HLGUT
      COMMON/GUTMES/LPPGUT,LTTGUT,LUGUT,LDGUT,LTGUT,LBGUT,LLGUT
      COMMON/MGUT/MGUT
      COMMON/FINETUN/FTSUSY,FTGUT,FTMES
      COMMON/EFFHIGM/MH,MMH,DMH,MA,MMA,DMA,MHC,MMHC,DMHC
      COMMON/EFFCOUP/PX,PA,PB,PL,PK
      COMMON/DELMB/DELMB
      COMMON/LHCSIG/SIG
      COMMON/HIGGSFIT/MHmin,MHmax,chi2max,chi2gam,chi2bb,chi2zz
      COMMON/GMSCEN/MSREF,D,DMIN,GMFLAG
      COMMON/M32/M32,CGR,MPL

      IF(IFAIL.NE.0)RETURN

      IRES=11
      NRES=106+IRES

      RES(1)=PAR(1)
      RES(2)=PAR(2)
      RES(3)=PAR(3)
      RES(4)=PAR(4)
      RES(5)=MMESS
      RES(6)=MSUSYEFF
      RES(7)=ALMES
      RES(8)=MSMES
      RES(9)=XIFMES
      RES(10)=XISMES
      RES(11)=XIU

      DO I=1,3
       RES(IRES-6+7*I)=SMASS(I)
       RES(IRES-5+7*I)=CV(I)
       RES(IRES-4+7*I)=CG(I)
       RES(IRES-3+7*I)=CJ(I)
       RES(IRES-2+7*I)=CU(I)
       RES(IRES-1+7*I)=CD(I)
       RES(IRES+7*I)=SCOMP(I,3)**2
      ENDDO
      DO I=1,2
       RES(IRES+16+6*I)=PMASS(I)
       RES(IRES+17+6*I)=CG(I+3)
       RES(IRES+18+6*I)=CJ(I+3)
       RES(IRES+19+6*I)=CU(I+3)
       RES(IRES+20+6*I)=CD(I+3)
       RES(IRES+21+6*I)=PCOMP(I,2)**2
      ENDDO
      DO I=1,3
       RES(IRES+33+I)=BRHAA(I,1)
      ENDDO
      DO I=1,4
       RES(IRES+36+I)=BRHHH(I)
      ENDDO
      DO I=1,5
       RES(IRES+40+I)=BRNEU(I,1,1)
      ENDDO
      DO I=1,3
       DO J=1,10
	RES(IRES+35+10*I+J)=SIG(I,J)
       ENDDO
      ENDDO
      RES(IRES+76)=chi2gam
      RES(IRES+77)=chi2bb
      RES(IRES+78)=chi2zz
      RES(IRES+79)=CMASS
      DO I=1,5
       RES(IRES+79+I)=DABS(MNEU(I))
      ENDDO
      RES(IRES+85)=NEU(1,1)**2
      RES(IRES+86)=NEU(1,3)**2+NEU(1,4)**2
      RES(IRES+87)=DABS(NEU(1,3)**2-NEU(1,4)**2)
      RES(IRES+88)=NEU(1,5)**2
      RES(IRES+89)=MCHA(1)
      RES(IRES+90)=MCHA(2)
      RES(IRES+91)=MGL
      RES(IRES+92)=MUR
      RES(IRES+93)=MUL
      RES(IRES+94)=MDR
      RES(IRES+95)=MDL
      RES(IRES+96)=MLR
      RES(IRES+97)=MLL
      RES(IRES+98)=MNL
      RES(IRES+99)=MST1
      RES(IRES+100)=MST2
      RES(IRES+101)=MSB1
      RES(IRES+102)=MSB2
      RES(IRES+103)=MSL1
      RES(IRES+104)=MSL2
      RES(IRES+105)=MSNT
      RES(IRES+106)=FTMES(NMES+1)

      WRITE(6,11)(RES(I),I=1,NRES)
 11   FORMAT(200E14.6)

      END


      SUBROUTINE ERROR(TOT,NTOT,NFAIL)

*********************************************************************
*   Subroutine for the error file. It contains a summary of the scan:
*   Number of points that passed/failed the tests
*   and ranges for scanned parameters that passed the tests
*********************************************************************

      IMPLICIT NONE

      INTEGER OMGFLAG,MAFLAG,MOFLAG,GMFLAG,I,S,TOT,NTOT,NFAIL(*)

      DOUBLE PRECISION MSUSYEFFN,MSUSYEFFNN,MMESSN,MMESSNN,TBN,TBNN
      DOUBLE PRECISION LN,LNN,KN,KNN,ALN,ALNN,XIFN,XIFNN,XISN,XISNN
      DOUBLE PRECISION MUPN,MUPNN,MSPN,MSPNN,MSN,MSNN,XIUN,XIUNN
      DOUBLE PRECISION LPPN,LPPNN,LTTN,LTTNN,LUN,LUNN,LDN,LDNN
      DOUBLE PRECISION LTN,LTNN,LBN,LBNN,LLN,LLNN,MUN,MUNN
      DOUBLE PRECISION MSREF,D,DMIN

      COMMON/FLAGS/OMGFLAG,MAFLAG,MOFLAG
      COMMON/BOUNDS/MSUSYEFFN,MSUSYEFFNN,MMESSN,MMESSNN,TBN,TBNN,
     . LN,LNN,KN,KNN,ALN,ALNN,XIFN,XIFNN,XISN,XISNN,MUPN,MUPNN,
     . MSPN,MSPNN,MSN,MSNN,XIUN,XIUNN,LPPN,LPPNN,LTTN,LTTNN,LUN,LUNN,
     . LDN,LDNN,LTN,LTNN,LBN,LBNN,LLN,LLNN,MUN,MUNN
      COMMON/GMSCEN/MSREF,D,DMIN,GMFLAG

      WRITE(0,20)"Number of points:                       "
      WRITE(0,*)
      WRITE(0,20)"  scanned                               ",NTOT
      WRITE(0,20)"  l, tan(beta) or mu=0                  ",NFAIL(9)
      WRITE(0,20)"  no electroweak symmetry breaking      ",NFAIL(20)
      S=0
      DO I=1,7
       S=S+NFAIL(I)
      ENDDO
      WRITE(0,20)"  with mh1^2 or ma1^2 or mhc^2 < 0      ",S
      WRITE(0,20)"  with m_sfermion^2 < 0                 ",NFAIL(8)
      WRITE(0,20)"  violating phenomenological constraints",NFAIL(10)
      IF(GMFLAG.NE.0)THEN
       WRITE(0,20)"  MSMES=/=MSREF                         ",NFAIL(21)
       WRITE(0,20)"  MSMES=/=MSREF + violating constraints ",NFAIL(22)
      ENDIF
      S=0
      DO I=11,15
       S=S+NFAIL(I)
      ENDDO
      WRITE(0,20)"  RGE integration problem               ",S
      S=0
      DO I=16,19
       S=S+NFAIL(I)
      ENDDO
      WRITE(0,20)"  convergence problem                   ",S
      WRITE(0,*)
      WRITE(0,20)"Remaining good points                   ",TOT
      IF(TOT.GT.0)THEN
       WRITE(0,*)
       WRITE(0,20)"Parameter ranges for good points:       "
       WRITE(0,*)
       WRITE(0,30)" MSUSYEFF: ",MSUSYEFFN,MSUSYEFFNN
       WRITE(0,30)" MMESS: ",MMESSN,MMESSNN
       WRITE(0,30)" TANB: ",TBN,TBNN
       WRITE(0,30)" LAMBDA: ",LN,LNN
       WRITE(0,30)" ALAMBDA: ",ALN,ALNN
       IF(GMFLAG.NE.0)
     .  WRITE(0,20)"(ALAMBDA is not an input parameter)"
       WRITE(0,30)"MUEFF: ",MUN,MUNN
       WRITE(0,20)"(MU is not an input parameter)"
       IF(MAFLAG.EQ.-3 .OR. MAFLAG.EQ.-4)THEN
        WRITE(0,30)" KAPPA: ",KN,KNN
        WRITE(0,30)" XIF: ",XIFN,XIFNN
        WRITE(0,20)"(XIF is not an input parameter)"
       ELSE
        WRITE(0,30)" KAPPA: ",KN,KNN
        WRITE(0,20)"(KAPPA is not an input parameter)"
        WRITE(0,30)" XIF: ",XIFN,XIFNN
       ENDIF
       IF(MAFLAG.EQ.-1 .OR. MAFLAG.EQ.-3)THEN
        WRITE(0,30)" XIS: ",XISN,XISNN
        WRITE(0,30)" MS^2: ",MSN,MSNN
        WRITE(0,20)"(MS^2 is not an input parameter)"
       ELSE
        WRITE(0,30)" MS^2: ",MSN,MSNN
        WRITE(0,30)" XIS: ",XISN,XISNN
        WRITE(0,20)"(XIS is not an input parameter)"
       ENDIF
       IF(MUPN.NE.0d0 .OR. MUPNN.NE.0d0)
     . WRITE(0,30)" MU': ",MUPN,MUPNN
       IF(MSPN.NE.0d0 .OR. MSPNN.NE.0d0)
     . WRITE(0,30)" MS'^2: ",MSPN,MSPNN
       IF(GMFLAG.EQ.1)
     . WRITE(0,30)" XIU: ",XIUN,XIUNN
       IF(GMFLAG.EQ.2)
     . WRITE(0,30)" LPP: ",LPPN,LPPNN
       IF(GMFLAG.EQ.2)
     . WRITE(0,30)" LTT: ",LTTN,LTTNN
       IF(GMFLAG.NE.0)
     . WRITE(0,30)" LU: ",LUN,LUNN
       IF(GMFLAG.NE.0)
     . WRITE(0,30)" LD: ",LDN,LDNN
       IF(GMFLAG.NE.0)
     . WRITE(0,30)" LT: ",LTN,LBNN
       IF(GMFLAG.NE.0)
     . WRITE(0,30)" LB: ",LBN,LBNN
       IF(GMFLAG.NE.0)
     . WRITE(0,30)" LL: ",LLN,LLNN

      ENDIF

 20   FORMAT(A40,I10)
 30   FORMAT(A15,2E15.4)

      END
